<?php
/** Somali (Soomaaliga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Abshirdheere
 * @author Maax
 * @author Mimursal
 * @author Yariiska
 */

$messages = array(
# User preference toggles
'tog-underline' => 'Linkiga hoos ka calaamadeysan:',
'tog-justify' => 'Geesdhig baaragaraafyada',
'tog-hideminor' => 'Qari bedelada yar ee isbedelada dhow',
'tog-hidepatrolled' => 'Qari wax bedelkii ugu danbeeyay oo la waardiyeeyay',
'tog-newpageshidepatrolled' => 'Ka qari maqaalada la waardiyeeyay maqaalada kale ee cusub',
'tog-extendwatchlist' => 'Balaari liiska waardiyaha si loo arko dhamaan isbedelada, ma ahan oo kaliya kuwa dhow',
'tog-usenewrc' => "Isticmaal isbdelada dhowdhow oo la'horumariyey (waxaa loo baahanyahay JavaScript)",
'tog-numberheadings' => 'Lambarada automaatik ahaan u tirinaayo Cinwaanada',
'tog-showtoolbar' => 'Itus bedelka qalabka shaqada (waxaa loo baahanyahay JavaScript)',
'tog-editondblclick' => 'wax ka bedel maqaalada labo jeer la riixay (waxaa loo baahanyahay JavaScript)',
'tog-editsection' => 'Fasax wax ka bedelida cutubyada dhinaca linkiyada [wax ka bedel]',
'tog-editsectiononrightclick' => 'Fasax cutub wax ka bedelida hadii batoonka midig ee dooliga <br /> dhag lagu siiyo cinwaanka korkiisa (JavaScript)',
'tog-showtoc' => "I'tus jadwalka (boggaga leh in kabadan 3 qoraalada sare)",
'tog-rememberpassword' => 'Kumbuyuutarkaan ku xasuusnaaw gudagalkeyga (ilaa  $1 {{PLURAL:$1|maalin|maalmood}})',
'tog-watchcreations' => 'Ku dar boggaga aan aniga sameeyay liiskayga waardiyaha',
'tog-watchdefault' => 'Ku dar boggaga aan wax ka bedelo liiskayga waardiyaha',
'tog-watchmoves' => 'Ku dar boggaga aan wareejiyo liiskayga waardiyaha',
'tog-watchdeletion' => 'Ku dar boggaga aan tirtiro liiskayga waardiyaha',
'tog-minordefault' => 'Isbedelada yaryar marwalba calaamadey',
'tog-previewontop' => 'Itus horfiirinta kahor sanduuqa wax ka bedelida',
'tog-previewonfirst' => 'Horfiirinta itus marka ugu horeeyso oo aan wax ka bedelo',
'tog-nocache' => 'Dami browsaha maqaalada duubo',
'tog-enotifwatchlistpages' => 'E-mail  ii soo dir markii  wax laga badalo maqaalada ku jira liiskayga waardiyaha',
'tog-enotifusertalkpages' => 'E-mail ii soo dir markii boggayga wadahadalka oo isbedelo',
'tog-enotifminoredits' => 'E-mail Ii soo dir xataa markii bedelo yar lagu sameeyo bogyada',
'tog-enotifrevealaddr' => 'Iigu soo bandhig cinwaankayga e-mailka ah fariimaha wargelinta',
'tog-shownumberswatching' => "I'tus tirada isticmaalayaasha wax waardiyeynaayo",
'tog-oldsig' => 'Saxiixa jiro:',
'tog-fancysig' => "u isticmaal saxiixa sida qoraalada wiki  (ayada oo linki auomaatik la'aan)",
'tog-uselivepreview' => 'Isticmaal horfiirinta tooska ah (JavaScript) (Wuxuu ku jiraa tijaabo)',
'tog-forceeditsummary' => "I'xasuusi markii uusan qoraalkeyga raacsiisnay faahfaahin gaaban",
'tog-watchlisthideown' => 'Ka qari wax bedelkeyga  liiska waardiyaha',
'tog-watchlisthidebots' => 'Ka qari bedelada robotka  liiska waardiyaha',
'tog-watchlisthideminor' => 'Ka qari  bedelyada yar liiska waardiyaha',
'tog-watchlisthideliu' => 'Ka qari isbedelada ee sameeyeen isticmaalada soo gelay liiska waardiyaha',
'tog-watchlisthideanons' => 'Ka qari isbedelada ee sameeyeen isticmaalada la aqoon liiska waardiyaha',
'tog-watchlisthidepatrolled' => 'Ka qari isbedelada la waardiyeeyay liiska waardiyaha',
'tog-ccmeonemails' => 'Ii soo dir e-mailada aan u diro isticmaalada kale oo koobi ah',
'tog-diffonly' => 'Kaladuwanaanshaha hoostooda qari qoraalka bogga',
'tog-showhiddencats' => 'Itusi ereykoobyada qarsoon',
'tog-norollbackdiff' => 'ha isticmaalin kala duwanaanshaha markii aad dib u soo celisay kadib',

'underline-always' => 'Marwalba',
'underline-never' => 'Marnaba',

# Font style option in Special:Preferences
'editfont-style' => 'Wax ku bedel meesha aad dooran kartid fartaada nuuceeda:',
'editfont-monospace' => 'Qoraalada nuuca kala waaweyn',
'editfont-sansserif' => 'Sans-serif nuucyada qoraalka',
'editfont-serif' => 'Serif nuucyada qoraalka',

# Dates
'sunday' => 'Axad',
'monday' => 'Isniin',
'tuesday' => 'Talaado',
'wednesday' => 'Arbaco',
'thursday' => 'Khamiis',
'friday' => 'Jimco',
'saturday' => 'Sabti',
'sun' => 'Axa',
'mon' => 'Isn',
'tue' => 'Tal',
'wed' => 'Arb',
'thu' => 'Kha',
'fri' => 'Jim',
'sat' => 'Sab',
'january' => 'Jannaayo',
'february' => 'Febraayo',
'march' => 'Maarso',
'april' => 'Abriil',
'may_long' => 'May',
'june' => 'Juun',
'july' => 'Luuliyo',
'august' => 'Agoosto',
'september' => 'Sebteembar',
'october' => 'Oktoobar',
'november' => 'Nofeembar',
'december' => 'Diseembar',
'january-gen' => 'Janaayo',
'february-gen' => 'Febraayo',
'march-gen' => 'Maarso',
'april-gen' => 'Abriil',
'may-gen' => 'May',
'june-gen' => 'Juun',
'july-gen' => 'Luuliyo',
'august-gen' => 'Agoosto',
'september-gen' => 'Sebteembar',
'october-gen' => 'Oktoobar',
'november-gen' => 'Nofeembar',
'december-gen' => 'Diseembar',
'jan' => 'Jan',
'feb' => 'Feb',
'mar' => 'Maar',
'apr' => 'Abr',
'may' => 'May',
'jun' => 'Juun',
'jul' => 'Luu',
'aug' => 'Ago',
'sep' => 'Seb',
'oct' => 'Okt',
'nov' => 'Nof',
'dec' => 'Dis',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Qeybta|Qeybaha}}',
'category_header' => 'Maqaalada ku jirta qeybta "$1"',
'subcategories' => 'Qeybaha hoose',
'category-media-header' => 'Wararka ku jiro qeybta"$1"',
'category-empty' => "''Qeybtaan hadda wax maqaal ah kuma jirto''",
'hidden-categories' => '{{PLURAL:$1|Qeybta qarsan|Qeybaha qarsan}}',
'hidden-category-category' => 'Qeybaha qarsoon',
'category-subcat-count' => '{{PLURAL:$2|Qeybtaan hadda waxaa ku jirto oo kaliya qeybtaan hoose.|Qeybtaan waxaa ku jirto {{PLURAL:$1|oo qeybta hoose|$1 oo ah qeybaha hoose}} waana $2 oo dhamaantood ah.}}',
'category-subcat-count-limited' => 'Qeybtaan waxaa ku jirto {{PLURAL:$1| oo ah qeybta hoose|$1 oo ah qeybaha hoose}}.',
'category-article-count' => '{{PLURAL:$2|Qeybtaan waxaa ku jirto intaan oo maqaal kaliya.| waxaa meeshaan ku jirto {{PLURAL:$1| oo maqaal|$1 oo maqaalo ah}} waxeena ku jiraan qeybtaan, waana  $2 oo dhamaantood ah.}}',
'category-article-count-limited' => 'Qeybtaan hadda waxaa ku jirto {{PLURAL:$1|oo maqaal|$1 oo maqaalo ah}}',
'category-file-count' => '{{PLURAL:$2|Qeybtaan waxaa ku jirto intaan oo maqaal kaliya.|waxaa meeshaan ku jirto {{PLURAL:$1| oo maqaal|$1 oo maqaalo ah}} waxeena ku jiraan qeybtaan, waana $2 oo dhamaantood.}}',
'category-file-count-limited' => 'Qeybtaan hadda waxaa ku jirto {{PLURAL:$1|oo maqaal|$1 oo maqaalo ah}}.',
'listingcontinuesabbrev' => 'kont',
'index-category' => 'Maqaalada indeksed',
'noindex-category' => 'Maqaalada noindeksed',
'broken-file-category' => 'Bog ka samaysan file aan jirin.',

'about' => 'Ku saabsan',
'article' => 'Qoraalka bogga oo kooban',
'newwindow' => '(dariishad cusub aa furmeeyso)',
'cancel' => 'Kansal',
'moredotdotdot' => 'wax kale',
'mypage' => 'Boggeyga',
'mytalk' => 'Wadahadalkeyga',
'anontalk' => 'Wadahadalka ciwaanka IP:kaan',
'navigation' => 'Gooshitaan',
'and' => '&#32;iyo',

# Cologne Blue skin
'qbfind' => 'Raadi',
'qbbrowse' => 'Ka soo raadi',
'qbedit' => 'Wax ka bedel',
'qbpageoptions' => 'Boggaan',
'qbmyoptions' => 'Boggageyga',
'qbspecialpages' => 'Bogaga qaaska ah',
'faq' => 'SIL',
'faqpage' => 'Project:SIL',

# Vector skin
'vector-action-addsection' => 'Hadal ku dar',
'vector-action-delete' => 'Tirtir',
'vector-action-move' => 'Wareeji',
'vector-action-protect' => 'Difaac',
'vector-action-undelete' => 'Ha tirtirin',
'vector-action-unprotect' => 'Bedel difaacida',
'vector-simplesearch-preference' => 'Shid kuwa ugu fiican oo kuu soo jeedinaayo raadinta  (Jirka vector kaliya)',
'vector-view-create' => 'Sameey',
'vector-view-edit' => 'Wax ka bedel',
'vector-view-history' => 'Itusi taariikhda',
'vector-view-view' => 'Akhri',
'vector-view-viewsource' => 'Itusi xogta',
'actions' => 'Waxa dhacaayo',
'namespaces' => 'Xarun magaceedyada',
'variants' => 'Isbedelada',

'navigation-heading' => 'Liiska laga galo',
'errorpagetitle' => 'Qalad',
'returnto' => 'Ku noqo $1.',
'tagline' => 'Ka {{SITENAME}}',
'help' => 'Caawinaad',
'search' => 'Raadi',
'searchbutton' => 'Raadi',
'go' => 'Soco',
'searcharticle' => 'Soco',
'history' => 'Taariikhda bogga',
'history_short' => 'Taariikh',
'updatedmarker' => 'Wax laga bedelay ilaa booqoshadaydii ugu dambeysay',
'printableversion' => 'Nooc la daabicikaro',
'permalink' => 'Linkiga daaimka ah',
'print' => 'Daabac',
'view' => 'Itusi',
'edit' => 'Wax ka bedel',
'create' => 'Sameey',
'editthispage' => 'Boggaan wax ka bedel',
'create-this-page' => 'Sameey boggaan',
'delete' => 'Tirtir',
'deletethispage' => 'Tirtir bogaan',
'undelete_short' => 'Ha tirtirin {{PLURAL:$1|hal bedel|$1  bedelood}}',
'viewdeleted_short' => 'Itusi {{PLURAL:$1|halxabo oo bedelkii la tirtiray|$1 bedelyadii la tirtiray}}',
'protect' => 'Difaac',
'protect_change' => 'Wax ka bedel',
'protectthispage' => 'Difaac boggaan',
'unprotect' => 'Bedel difaacida',
'unprotectthispage' => 'Bedel difaacida boggaan',
'newpage' => 'Bog cusub',
'talkpage' => 'Wadahadalka boggan',
'talkpagelinktext' => 'Wadahadal',
'specialpage' => 'Bogaga qaaska ah',
'personaltools' => 'Qalabkaaga',
'postcomment' => 'Maqaal cusub',
'articlepage' => 'Fiiri bogga qoraalka',
'talk' => 'Wadahadal',
'views' => 'Muuqaalka',
'toolbox' => 'Qalabka shaqada',
'userpage' => 'Itus bogga isticmaalaha',
'projectpage' => 'Itus bogga mashruuca',
'imagepage' => 'Itusi faylka bogga',
'mediawikipage' => 'Fiiri bogga fariinta',
'templatepage' => 'Fiiri bogga tusmada',
'viewhelppage' => 'Fiiri bogga caawinaada',
'categorypage' => 'Itusi qeybta bogga',
'viewtalkpage' => 'Fiiri bogga wadahadalka',
'otherlanguages' => 'Luqadaha kale',
'redirectedfrom' => '(Waxaa laga soo toosiyay $1)',
'redirectpagesub' => 'Bogga loo sii toosiyay',
'lastmodifiedat' => 'Boggan waxaa markii ugu dambeysay wax laga bedelay $2, $1.',
'viewcount' => 'Boggaan waxaa soo booqday {{PLURAL:$1|mar|$1 jeer}}.',
'protectedpage' => "Bogga la'difaacay",
'jumpto' => 'U bood:',
'jumptonavigation' => 'gooshitaan',
'jumptosearch' => 'raadi',
'view-pool-error' => 'Naga raali noqo, kombiyutarkaan hadda wuu buuxsamay.
Isticmaaleyaal aad u badan ayaa fiirinooyo boggaan.
Fadlan sug xoogaa intii aadan soo gelin boggaan.

$1',
'pool-timeout' => 'Waqtiga wuu ka dhamaaday xiritaanka',
'pool-queuefull' => 'Safka shaqeenta Pool woo buuxsamay',
'pool-errorunknown' => 'Qalad la aqoon',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Ku saabsan {{SITENAME}}',
'aboutpage' => 'Project:ku saabsan',
'copyright' => 'Qoraalka wuxuu ku salaysanyahay $1.',
'copyrightpage' => '{{ns:project}}: Ogolaashada koobiga',
'currentevents' => 'Dhacdooyinka cusub',
'currentevents-url' => 'Project:Dhacdooyinka Hadda',
'disclaimers' => "Masuul la'aan",
'disclaimerpage' => "Project:Masuul la'aan guud",
'edithelp' => 'Caawinaada wax ka bedelka',
'helppage' => 'Help:Caawinaad',
'mainpage' => 'Bogga Hore',
'mainpage-description' => 'Bogga Hore',
'policy-url' => 'Project: Xeerka',
'portal' => 'Albaabka Bulshada',
'portal-url' => 'Project:Albaabka bulshada',
'privacy' => 'Xeerka Wiki',
'privacypage' => 'Project:Xeerka Wiki',

'badaccess' => 'Qalad dhinaca ogolaashada',
'badaccess-group0' => 'Laguuma ogolo in aad sameyso waxa aad rabtid',
'badaccess-groups' => 'Dalabkaan wuxuu u gaar yahay isticmaaleyaasha ka mid ah {{PLURAL:$2|kooxda|kooxahaan}}: $1.',

'versionrequired' => 'Nuuca  $1 oo MediaWiki ah aa loo baahanyahy',
'versionrequiredtext' => 'Nooca $1 ee MediaWiki aa loo baahanyahay in lagu isticmaalo boggaan.
fiiri [[Special:Version|nooca bogga]].',

'ok' => 'waayahay',
'retrievedfrom' => 'Waxaa laga keenay "$1"',
'youhavenewmessages' => 'Waxaa heysataa $1 ($2).',
'newmessageslink' => 'Fariimaha cusub',
'newmessagesdifflink' => 'bedelkii ugu dambeeyay',
'youhavenewmessagesfromusers' => 'Waxay $1 kaaga timid {{PLURAL:$3|adeegsade kale|$3 adeegsade}} ($2).',
'youhavenewmessagesmanyusers' => 'Waxay ka $1 timid adeegsade yaal farabadan ($2).',
'newmessageslinkplural' => '{{PLURAL:$1|Waa fariin cusub|fariin cusub}}',
'newmessagesdifflinkplural' => '$1 {{PLURAL:$1|bedelkii ugu dambeeyey|bedeladii ugu dambeeyey}}',
'youhavenewmessagesmulti' => '$1 waxaa kuu yaalo fariimo cusub',
'editsection' => 'Wax ka bedel',
'editold' => 'Wax ka bedel',
'viewsourceold' => 'Itusi xogta',
'editlink' => 'wax ka bedel',
'viewsourcelink' => 'Itusi xogta',
'editsectionhint' => 'Wax ka bedel: $1',
'toc' => 'Qoraalka gudaha oo kooban',
'showtoc' => "I'tus",
'hidetoc' => 'qari',
'collapsible-collapse' => 'woo halaabay',
'collapsible-expand' => 'Sii balaari',
'thisisdeleted' => 'Fiiri ama soo celi $1?',
'viewdeleted' => 'Fiiri $1?',
'restorelink' => '{{PLURAL:$1|halxabo oo bedelkii la tirtiray|$1 bedelyadii la tirtiray}}',
'feedlinks' => 'Quudinta wararka:',
'feed-invalid' => 'Habka aad uga soo qayb gashay masaxna.',
'feed-unavailable' => 'Faallo diyaar maaha.',
'site-rss-feed' => '$1 RSS quudiye',
'site-atom-feed' => '$1 Atom quudiye',
'page-rss-feed' => '"$1" RSS quudiye',
'page-atom-feed' => '"$1" Atom quudiye',
'red-link-title' => '$1 (Bogga ma jiro)',
'sort-descending' => 'Habka hoos udhaca.',
'sort-ascending' => 'Habka kor u kaca.',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Bog',
'nstab-user' => 'Bogga isticmaalaha',
'nstab-media' => 'Bogga wararka',
'nstab-special' => 'Bogga khaaska ah',
'nstab-project' => 'Bogga mashruuca',
'nstab-image' => 'Gal',
'nstab-mediawiki' => 'Fariin',
'nstab-template' => 'Tusmo',
'nstab-help' => 'Bogga caawinaada',
'nstab-category' => 'Qeybta',

# Main script and global functions
'nosuchaction' => 'Wax shaqo oo saas ah kama jiro',
'nosuchactiontext' => 'Waxaad soo raacday URL aan sax ahayn.
waxaa laga yaabaa URL inaad u qortay hab aan sax ahayn, ama aad soo raacday mid aan jirin.
waxaa laga yaabaa inuu kani tilmaamayo cilad jirta  {{SITENAME}}.',
'nosuchspecialpage' => 'Wax bog oo sidaas khaas u ah ma jirto.',
'nospecialpagetext' => '<strong>Waxaana weydiisay bog khaas ah oosan jirin.</strong>

Waxaa meeshaan ka heli kartaa liiska bogyaasha khaaska ah oo jiro  [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error' => 'Qalad',
'databaseerror' => 'Qalad ka dhacday database;ka',
'laggedslavemode' => 'Digniin: Waxaa lagayaabaa bogaan in uusan wax cusub ku soo kordhin.',
'readonly' => 'Databaska waa la xiray',
'enterlockreason' => 'Ku qor sababta loo xiraayo, kuna siidar waqtigii la soo fasaxaayo maqaalka.',
'missing-article' => 'Database-ka ma soo helin qoraalkii bogga oo laga rabay in oo soo helo, oo la dhoho  "$1" $2.

Waxaan oo kale waxaa sabab ugu ah soo raacida linkiga duqoobay ee duwanaan ama taariikh oo kula xiriirtay bog la tirtitay.
Hadii ee sidaas eheen, waxaa laga yaabaa in software-ka aad qalad ka heshay.
Fadlan u sheek [[Special:ListUsers/sysop|maamulaha]], kana digtooneesii URL-ka.',
'missingarticle-rev' => '(bedelaadka#: $1)',
'missingarticle-diff' => '(Duwanaan: $1, $2)',
'internalerror' => 'Qalad gudaha ah',
'internalerror_info' => 'Qalad gudaha ah: $1',
'fileappenderrorread' => 'Ma akhri karin "$1" markii oo ku daraayay.',
'fileappenderror' => 'Ma ku dari karin "$1" ilaa  "$2".',
'filecopyerror' => 'Ma koobi gareen karin faylka "$1" ilaa "$2".',
'filerenameerror' => 'Maka bedeli karin magaca faylka  "$1" ilaa "$2".',
'filedeleteerror' => 'Ma tirtiri karin faylka "$1".',
'directorycreateerror' => 'Ma sameyn karin maktabad "$1".',
'filenotfound' => 'Ma oo san helin  faylka "$1".',
'fileexistserror' => 'Ma ku qori karin faylka "$1": faylkan wuu jiraa.',
'unexpected' => 'Qiimo loo maleeneenin: "$1"="$2".',
'formerror' => 'Qalad: suura gal maaha in la diraa qoraalkaan',
'badarticleerror' => 'Shaqadaan ma lagu sameyn karo boggaan.',
'cannotdelete' => 'Boggaan ama file\'ka "$1" mala tirtiri karo.
waxaa laga yaabaa in oo qof kale tirtiray .',
'cannotdelete-title' => 'Ma tirtiri karo bogga "$1"',
'badtitle' => 'Qoraal xun',
'badtitletext' => 'Bogga aad rabtay ciwaankiisa sax ma eheen, waa ebar, ama waa erayo qalad oo la xiriiro isdhaafka-luqadaha ama isdhaafka-ciwaanka wiki.
Waxaa ku jiri kara xuruufo aanan loo isticmaalikarin cinwaan ahaan.',
'viewsource' => 'Itusi xogta',
'actionthrottled' => 'Shaqada waala ceejiyay',
'actionthrottledtext' => 'Hadii aan ahay ka hortaga spamka, laguuma ogolo  shaqadaan badan oo waqti sidaan u yar ku qabatay,waadna ku xad gudubtay halihii laguu oglolaa.
fadlan waxyar kadib ku soo noqo.',
'protectedpagetext' => 'Boggaan  waala difaacay si aan wax looga bedelin.',
'viewsourcetext' => 'Waad fiirin kartaa waana koobi gareen kartaa xogta boggaan:',
'editinginterface' => "'''Digniin:''' Waxaad guda gashay inaad badesho bogga lawada arkayo wajiga hore ee qoraalka softwareka.
Waxa uu saameeyn ku yeelan doonaa boggaan habka uu wax u arko adeegsadaha iyo dhamaan adeegsadayaasha ee wikgaan.
Si aad wax ugu kordhiso ama aad uga dhinto turjumaadda mashaariicda wikiga , fadlan adeegso [//translatewiki.net/ translatewiki.net], mashruuca gaarka ah ee MediaWiki.",
'cascadeprotected' => 'Boggaan waxaa laga difaacay in wax laga bedelo, sababtoo ah wuxuu ka midyahay  {{PLURAL:$1|bog, oo ah |bogyaalo ah, waana}}  kuwa laga difaacay "qoraalada kaskadka ah" dooqyada woo u furanyahay:
$2',
'namespaceprotected' => "Ma laguu ogolo in aad wax ka bedesho maqaalada ku jirto '''$1''' xarun magaceedka.",
'customcssprotected' => "Ma laguu ogolo in aad wax ka badashid boggaan, sababtoo ah waxaa ku qoran isticmaale'yaal kale waxyaabo u shaqsi ah.",
'ns-specialprotected' => 'Bogyaasha gaarka ah wax malaga bedeli karo.',
'titleprotected' => 'Qoraalkaan aad qortay waxaa difaacay  [[User:$1|$1]] si loo sameynin.
Sababta neh waxaa waaye "\'\'$2\'\'".',

# Virus scanner
'virus-scanfailed' => 'baaritaanka woo shaqeesmi waayay (koodka $1)',
'virus-unknownscanner' => 'ka hor tagga fayruska la aqoon:',

# Login and logout pages
'logouttext' => "'''Hada waad ka baxday.'''

Waad sii isticmaali kartaa {{SITENAME}} adoona lagu aqoon, ama <span class='plainlinks'>[$1 gudaha gal]</span> adiga oo isticmaalaya magacaagii hore ama mid ka duwan. OGEYSIIS waxaa lagayabaa bogyaasha qaarkood in ay yiraahdaan wali gudaha ayaad ku jirtaa, ilaa inta aad ka nadiifineesid browsahaaga Internetka.",
'welcomeuser' => 'Soo dhowoow, $1',
'yourname' => 'Magaca gudagalka:',
'userlogin-yourname' => 'Magaca gudagalka',
'userlogin-yourname-ph' => 'Gasho magacaada kuu gaarka ah',
'yourpassword' => 'Eraysir:',
'userlogin-yourpassword' => 'Erey sir',
'userlogin-yourpassword-ph' => 'Gali erey sir',
'createacct-yourpassword-ph' => 'Gali erey sir',
'yourpasswordagain' => 'Markale qor ereysirka:',
'createacct-yourpasswordagain' => 'Hubi erey sirta',
'createacct-yourpasswordagain-ph' => 'Mar kale gali erey sirta',
'remembermypassword' => 'Kumbuyuutarkaan ku xasuusnaaw magaceyga gudagalka (ilaa  $1 {{PLURAL:$1|maalin|maalmood}})',
'userlogin-remembermypassword' => 'Ka dhig mid diyaar ah mar waliba',
'userlogin-signwithsecure' => 'Adeegso khad la hubo',
'yourdomainname' => 'Magacaga shabakada',
'password-change-forbidden' => 'Ma badali kartid Eraysir ee wiki.',
'login' => 'Gudaha gal',
'nav-login-createaccount' => 'Gudaha gal / sameyso akoon',
'loginprompt' => "Waa in aad shidaa cookies'ka hadii aad rabto in aad soo gasho {{SITENAME}}.",
'userlogin' => 'Gudaha gal / sameyso akoon',
'userloginnocreate' => 'Gudaha gal',
'logout' => 'Ka bax',
'userlogout' => 'Ka bax',
'notloggedin' => 'Gudaha kuma jirtid',
'userlogin-noaccount' => 'Akoon ma heysatid?',
'userlogin-joinproject' => 'Ku biir {{SITENAME}}',
'nologin' => 'Akoon ma heysatid? $1.',
'nologinlink' => 'Akoon sameyso',
'createaccount' => 'Sameey gudagale',
'gotaccount' => "Waan heystaa gudagale? '''$1'''.",
'gotaccountlink' => 'Gudaha gal',
'userlogin-resetlink' => 'Ma ilaawday tafaasiisha gudagalahaada?',
'userlogin-resetpassword-link' => 'Dib usoo cesho erey sirtaada',
'userlogin-helplink' => '[[{{MediaWiki:helplogin-url}}|Caawinaad habka gudagalka]]',
'createacct-join' => 'Gali macluumaadkaada gaarka ah.',
'createacct-emailoptional' => 'Ciwaanka e-mail-ka (dooqasho)',
'createacct-email-ph' => 'Gali Ciwaankaada e-mail-ka',
'createaccountmail' => 'E-mail ahaan',
'createaccountreason' => 'Sababta:',
'createacct-captcha' => 'Hubin amni',
'createacct-imgcaptcha-ph' => 'Gali qoraalka aad kor ku aragto',
'createacct-submit' => 'Sameeyso akoonkaada',
'createacct-benefit-heading' => 'Bogga {{SITENAME}} waxaa sameeyey dad kula mid ah.',
'createacct-benefit-body1' => '{{PLURAL:$1|bedel|bedelaadyo}}',
'createacct-benefit-body2' => '{{PLURAL:$1|bog|Bogag}}',
'createacct-benefit-body3' => '{{PLURAL:$1|contributor|wax qoreyaasha}}',
'badretype' => 'Ereyada sirta ah oo qortay ma islahan.',
'userexists' => 'Magaca isticmaalaha aad qortay wuu jiraa.
Fadlan dooro magac kale.',
'loginerror' => 'Qalad gudagalista',
'createacct-error' => 'Qalad dhacay samaynta akoonka',
'createaccounterror' => 'Ma sameeyn karin akoon: $1',
'nocookiesnew' => "Akoonka isticmaalahaan waa la sameeyay, laakiin adiga gudaha uma soo gelin.
{{SITENAME}} wuxuu isticmaalaa cookies si ee gudaha u galaan isticmaale yaasha.
Adiga cookies'kaaga wuu dansanyahay .
Fadlan shid, kadib neh gudaha ku gal magacaaga isticmaalaha cusub iyo ereygaaga sirta ah.",
'nocookieslogin' => "{{SITENAME}} wuxuu isticmaalaa cookies si ee isticmaaleyaasha u gudagalaan.
Cookies'kaaga woo dansanyahay.
Fadlan shid markale neh ku noqo.",
'nocookiesfornew' => "Magacaan isticmaalaha lama sameyn, waana diiwan galin weynay ereykoodkiisa.
Waa in aad hubsataa in aad shiday cookies'kaaga, ku soo noqo boggaan markale neh baroobeey.",
'noname' => 'Ma jiro magaca isticmaalaha aad qortay',
'loginsuccesstitle' => 'Gudagalida waa la dhamaystiray',
'loginsuccess' => "'''Waxaa hadda gudaha ugu soo gashay {{SITENAME}} sida \"\$1\".'''",
'nosuchuser' => 'Ma jiro isticmaalo leh magacaan "$1".
Magacyada way kala waaweyn yihiin.
Sax hingaada, ama  [[Special:UserLogin/signup|samayso magac gudagale ah]].',
'nosuchusershort' => 'Majiro isticmaale leh magacaan "$1". Sax qoraalkaaga.',
'nouserspecified' => 'Waa in aad magac gudagale heshaa.',
'login-userblocked' => 'Isticmaalahaan waa la mamnuucay. Lama ogolo in oo gudaha u galo',
'wrongpassword' => 'Ereyga sirta ah waa qalad. Fadlan iskuday markale.',
'wrongpasswordempty' => 'Erayga sirta aad qortay wuxuu ahaa ebar. Fadlan iskuday markale.',
'passwordtooshort' => 'Erayada sirta ah waa in oo ahaadaa ugu yaraan  {{PLURAL:$1|1 xaraf|$1 xarfood}} .',
'password-name-match' => 'Eraygaaga sirta ah waa in oo ka badalnaadaa magacaaga gudagale',
'password-login-forbidden' => 'Waxaa laga joojiyey adeegsiga magacaan iyo nambar sirtiisaba.',
'mailmypassword' => 'E-mail iigu soo dir ereysir cusub',
'passwordremindertitle' => 'Eraysir ku meelgaar ah oo loogu talagalay {{SITENAME}}',
'passwordremindertext' => 'Qof (laga yaabo in aad adiga tahay, kana soo galay cinwaanka-IP-ka  $1) ayaa eraysir oo cusub u codsaday  {{SITENAME}}  ($4).
Eraysir oo ku meelgaar ah oo loogu talagalay isticmaalaha "$2" ayaa la sameeyay waxaana loo diray "$3".
Hadii uu ahaa qofka rabay, waxaa la rabaa in aad hadda gudaha u gashid isla markaas neh eraysir cusub dooratid.
Eraygaan sirta oo ku meelgaarka ah wuxuu dhici doonaa ilaa  {{PLURAL:$5|maalin|$5 maalmood}}.

Hadii u qofkale sameeyay codsigaan, ama aad soo xasuusatay eraysirkaagii,
oo aadan u baahnayn in aad bedeshid, iska ilow farriintaan siina wado eraysirkaagi hore.',
'noemail' => 'E-mailkiisa lama haayo isticmaalaha  "$1".',
'noemailcreate' => 'Waa in aad ciwaan e-mail oo sax ah keentaa.',
'passwordsent' => 'Eraysir oo cusub ayaa e-mail loogu diray isticmaalaha "$1".
Fadlan gudaha u gal markii aad fariintaas heshid.',
'blocked-mailpassword' => 'Cinwaankaada IP:ka waxaa laga mamnuucay in oo wax bedelo, sidoo kale looma ogolo in oo bedelo ereyga sirta ah si oo uuga fakado danbiga lagu heesto',
'eauthentsent' => "Xaqiijin e-mail ah ayaa loo  diray e-mailkan aad dooratay.
Intii aadan wax e-mail ah lagu soo dirin koontada, waa in aad daba kacdaa waxa kuugu jiro e-mailka, si aad u xaqiijisid  in aad adiga  leedahay akoon'ka.",
'mailerror' => 'Qalad dirida e-mailka: $1',
'acct_creation_throttle_hit' => "Dadka soo booqanaayo wiki:gaan oo isticmaalaayo cinwaankaaga IP:ka waxay sameeyeen {{PLURAL:$1|1 magac gudagale ah|$1 magac  gudagalayaal ah}} maalintii ugu dambeysay, taasina waa inta ugu badan ee la'ogolyahay muddadaas. Sidaas daraadeed, booqoshadayaasha isticmaalaya cinwaankaan-IP:ka hadda ma'sameysankaraan magac gudagale danbe.",
'emailauthenticated' => 'E-mailkaada waxaa lagu xaqiijiyay $2 markey ahayd $3.',
'emailnotauthenticated' => 'Ciwaankaada e-mailka weli lama xaqiijinin.
Wax e-mail ah oo ku saabsan arrimaha soo socdo looma soo diridoono.',
'emailconfirmlink' => 'Soo xaqiiji ciwaankaada e-mailka',
'invalidemailaddress' => 'e-mailkaan lama ogolaan karo ayada oo ku ku jirto format la aqoonsan..
Fadlan ku qor ciwaan leh format sax ah ama ebar ka dhig  meesha.',
'accountcreated' => "Akoon aa la'sameeyay",
'accountcreatedtext' => "Akoonka isticmaalaha $1 waa la'sameeyay.",
'createaccount-title' => 'Waxaa akoon loo sameeyay {{SITENAME}}',
'createaccount-text' => 'Qof aa akoon ka sameesatay e-mailkaada  {{SITENAME}} ($4) waxaa la dhahaa "$2", ereygeeda sirka ah waa "$3".
Waa in aad hadda gudaha u gashaa oo bedeshaa ereygaada sirka ah.

Waa iska dhago tiri kartaa fariintaan, hadii akoonkaan oo ku sameysmay qalad.',
'login-throttled' => 'wax badan ayaa isku dayday in aad soo gasho.
Fadlan waxyar sug intii aadan soo gelin.',
'login-abort-generic' => 'Ma u soo gali karin gudaha - waa la noqay',
'loginlanguagelabel' => 'Luqada: $1',

# Email sending
'user-mail-no-addy' => "Isku dayday in aa dirto e-mail ayada oo ciwaan e-mail la'aan ah.",

# Change password dialog
'resetpass' => 'Bedel ereysirka',
'resetpass_announce' => 'waxaa ku soo geshay eraysir ku meelgaar ah  oo e-mail laguugu soo diray.
Hadii aad rabtid in aad dhameestirtid gudagelkaaga, waa in aad meeshaan ku qortaa eraysir oo cusub:',
'resetpass_header' => 'bedel  ereyga sirta ee akoon-ka',
'oldpassword' => 'Ereysirkii hore:',
'newpassword' => 'Ereysir cusub:',
'retypenew' => 'Qor mar labaad ereysirka cusub:',
'resetpass_submit' => 'Qor eraysirka gudaha neh gal',
'changepassword-success' => 'Ereysirkaada si fiican oo kuugu bedelmay!
Hadda gudaha ku gal',
'resetpass_forbidden' => 'ereyada sirta ah mala bedeli karo',
'resetpass-no-info' => 'Waa in aad gudaha u gashaa hadii aad rabto in aad si toos ah ugu soo gudubto boggaan.',
'resetpass-submit-loggedin' => 'bedel ereysirka',
'resetpass-submit-cancel' => 'Kansal',
'resetpass-temp-password' => 'Ereysir ku meel gaar ah:',

# Special:PasswordReset
'passwordreset' => 'Bedel ereysirka',
'passwordreset-text-many' => '{{PLURAL:$1|Gali mid ka mid ah macluumaadkaada asaasiga ah si erey sirtaada usoo ceshato.}}',
'passwordreset-legend' => 'Bedel ereysirka',
'passwordreset-username' => 'Magaca gudagalka',
'passwordreset-email' => 'Ciwaanka e-mailka',
'passwordreset-emailtext-ip' => "(Qof laga yaabo in ee tahay adi, oo ka socdo ciwaanka IP'ka $1)  ayaa  codsaday xasuus faah faahin akoonkaada {{SITENAME}}
($4). Isticmaaladaan soo socota {{PLURAL:$3|akoonkooda waxee|akoonkooda waxee}} la xiriiraan ciwaankaan e-mailka ah:

$2

{{PLURAL:$3|eraysirkaan kumeel gaarka ah|Eraysiryadaan kumeel gaarka ah}} waxay dhacaayaan {{PLURAL:$5|hal maalin|$5 maalmood}}.
Waa in aad gudaha gashaa oo e-mail cusub doorataa hadda. Hadii ee qof kale codsigaan sameysay, ama hadii aad soo xasuusatay eraysirkaagii hore, oo aadna u baahneen in aad badashid, iska ilaaw fariintaan siina isticmaal eraysirkaagii duqi ahaa.",
'passwordreset-emailtext-user' => 'Isticmaale $1 ee {{SITENAME}} wuxuu codsaday xasuus faah faahin akoonkaada {{SITENAME}}
($4). Isticmaaladaan soo socota {{PLURAL:$3|akoonkooda waxee|akoonkooda waxee}} la xiriiraan ciwaankaan e-mailka ah:

$2

{{PLURAL:$3|eraysirkaan kumeel gaarka ah|Eraysiryadaan kumeel gaarka ah}} waxay dhacaayaan {{PLURAL:$5|hal maalin|$5 maalmood}}.
Waa in aad gudaha gashaa oo e-mail cusub doorataa hadda. Hadii ee qof kale codsigaan sameysay, ama hadii aad soo xasuusatay eraysirkaagii hore, oo aadna u baahneen in aad badashid, iska ilaaw fariintaan siina isticmaal eraysirkaagii duqi ahaa.',
'passwordreset-emailelement' => 'Magaca gudagalka: $1
Ereysirka kumeelgaarka ah: $2',
'passwordreset-emailerror-capture' => 'E-mail xasuus ah ayaa la sameeyay, oo ka arki kartid hoosta,laakiin wuxuu ku guul dareestay in isticmaalaha loo diro: $1',

# Special:ChangeEmail
'changeemail' => 'Bedel ciwaanka E-mailka',
'changeemail-header' => 'Bedel ciwaanka e-mailka akoonka',
'changeemail-oldemail' => 'Ciwaanka e-mailka hadda jiro:',
'changeemail-newemail' => 'Ciwaan e-mail oo cusub:',
'changeemail-none' => '(waxna)',
'changeemail-submit' => 'Bedel e-mailka',
'changeemail-cancel' => 'Ka noqo',

# Edit page toolbar
'bold_sample' => 'Far butac ah',
'bold_tip' => 'Far butac ah',
'italic_sample' => 'Farta caatada ah',
'italic_tip' => 'Farta caatada ah',
'link_sample' => 'Qoraalka linkiga',
'extlink_sample' => 'http://www.example.com qoraalka linkiga',
'extlink_tip' => 'Xiriirka tixraaca (xasuuso http:// prefix)',
'headline_sample' => 'Qoraalka madaxa hore',
'headline_tip' => 'Qeybta 2aad ee ciwaanka kore',
'nowiki_sample' => 'Ku dar meeshaan qoraal aan la format-gareen',
'nowiki_tip' => 'Iska dhagooleey formatka wiki',
'image_tip' => 'Fayl la soo galiyay',
'media_tip' => 'Linkiga file-ka',
'sig_tip' => 'Saxiixaaga oo waqti ku dhufsan',

# Edit pages
'summary' => 'Qoraal kooban:',
'minoredit' => 'Kan waa wax ka bedel yar',
'watchthis' => 'Boggaan waardiyey',
'savearticle' => 'Bogga kaydi',
'preview' => 'Horfiirin',
'showpreview' => 'Itus horfiirinta',
'showlivepreview' => 'Horfiirin toos ah',
'showdiff' => 'Itus isbedelka',
'anoneditwarning' => "'''Digniin:''' Gudaha kuma jirtid. Cinwaankaaga IP:ga waxaa lagu diiwaangelindoonaa taariikhda bedelida bogan.",
'anonpreviewwarning' => "''Ma soo gelin. Hadii aad keydisid waxaa ciwaankaada  IP:ka  lagu duubaa taariikhda bedelka boggaan.''",
'missingcommenttext' => 'Fadlan ku qor  hoostaan  hadalkaaga.',
'blockedtitle' => 'Isticmaalaha waa la mamnuucay',
'blockedtext' => "'''Magacaaga isticmaalaha ama ciwaanka IP'ka waa la mamnuucay.'''

Mamnuucida waxaa sameeyay  $1.
Sababta neh waxaa waaye  ''$2''.

* Mamnuucida wuxuu bilaamay: $8
* Mamnuucida wuxuu dhamaanaa: $6
* Ku aadan mamnuucida: $7

Waxaa la  xiriiri kartaa $1 ama mid ka mid ah  [[{{MediaWiki:Grouppage-sysop}}|maamulada]] kale si aad uula muranto mamnuucida.
Ma isticmaali kartid 'e-mailka isticmaalahaan' soo diray hadii aad heesato maa hinee ciwaan e-mail oo kuugu jiro  [[Special:Preferences|koontadaada]] oona lagaa mamnuucin in aad isticmaasho.
Ciwaankaada  IP'ka waa $3, ID'ga la mamnuucay neh waa  #$5.
fadlan ku soo dar su'aalahaaga waxa kor ku qoran.",
'autoblockedtext' => "Ciwaankaaga IP'ka waxaa loo mamnuucay si automaatik ah sababtoo ah waxaa isticmaalay isticmaale kale, oo mamnuucay  $1.  Sababta neh waa tan:
:''$2''

* Mamnuucida wuxuu bilaamay: $8
* Mamnuucida wuxuu dhamaanaa: $6
* Ku aadan mamnuucida: $7

Waxaa la  xiriiri kartaa $1 ama mid ka mid ah  [[{{MediaWiki:Grouppage-sysop}}|maamulada]] kale si aad uula muranto mamnuucida.
Ma isticmaali kartid 'e-mailka isticmaalahaan' soo diray hadii aad heesato maa hinee ciwaan e-mail oo kuugu jiro  [[Special:Preferences|koontadaada]] oona lagaa mamnuucin in aad isticmaasho.
Ciwaankaada  IP'ka waa $3, ID'ga la mamnuucay neh waa  #$5.
fadlan ku soo dar faahfaahinta ku qoran kor su'aalo kasto oo sameyso.",
'blockednoreason' => 'wax sabab ah kama bixin',
'whitelistedittext' => 'Waa in aad $1 si aad wax uga bedeshid boggaga.',
'confirmedittext' => 'Waa in aad xaqiijisaa e-mailkaada inta aadan bogaga wax ka bedelin.
fadlan ku dar kuna xaqiiji e-mailkaada meesha  [[Special:Preferences|dooqyada gudagalahaaga]].',
'nosuchsectiontitle' => 'Qaybtaan lama heli karo',
'nosuchsectiontext' => 'Waxaa baroobeysay in aad wax ka bedesho maqaal jirin.
Waxaa laga yaabaa in la wareejiyay ama la tirtiray adiga oo fiirinaayo bogga.',
'loginreqtitle' => 'Waxaa loo baahanyahay gudagalid',
'loginreqlink' => 'Gudaha gal',
'loginreqpagetext' => 'Waa in aad $1 si aad u fiirisid bogyaasha kale.',
'accmailtitle' => "Ereysirka waa la'diray.",
'accmailtext' => "Ereysir loogu tala galay [[User talk:$1|$1]] waxaa loogu diray $2.

Akoonkaan cusub eraysirkiisa waxaa ku badali kartaa  bogga ''[[Special:ChangePassword|bedel eraysirka]]'' si aad u soo gashid.",
'newarticle' => '(Cusub)',
'newarticletext' => "Waxaa soo raacday link kula soo xiriiriyay bog oo hadda wali jirin.
Hadii aad rabto in aad sameyso bogga, hoos ka bilaaw qoraalkaada (fiiri [[{{MediaWiki:Helppage}}|bogga caawinaada]] wax war ah oo kale).
hadii aad meeshaan ku soo qaldantay, riix batoonka barowsahaaga  '''gadaal uuga noqo''' .",
'anontalkpagetext' => "----''Meeshaan waa bogga wadahadalka isticmaalayaasha la aqoon oo aanan weli sameysanin akoon, ama  wali isticmaalin. 
Sidaas darteed, waa in aan isticmaalnaa lambar cinwaaneedka IP:ga si aan u ogaano asiga/ayada. Cinwaanka IP:ga waxaa suurto gal ah in ay qeybsadaan isticmaaleyaal badan.
Hadii aad tahay isticmaale aanan la'aqoonsanin oo aad dareemaysid in laguu gafay, fadlan  [[Special:UserLogin/signup|sameyso akoon]]  ama [[Special:UserLogin|gudaha gal]] si aad u dhowrsatid in hadhowdi laguugu qaldo isticmaalada kale oo aann la'aqoonsanin.''",
'noarticletext' => 'Boggaan hadda wax qoraal ah kuma qorno.
Waxaa  [[Special:Search/{{PAGENAME}}|magaca boggaan]] ka raadin kartaa bogyaasha kale,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} raadi kuwo la mid ah],
ama [{{fullurl:{{FULLPAGENAME}}|action=edit}} wax ka bedel boggaan]</span>.',
'noarticletext-nopermission' => 'Hadda boggaan wax qoraal ah kuma qorno.
Waxaa  [[Special:Search/{{PAGENAME}}|magaca boggaan ka raadin kartaa]] boggaga kale ama <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} ka raadi gudagalayaasha kale]</span>.',
'userpage-userdoesnotexist' => 'Isticmaalahan  "<nowiki>$1</nowiki>" ma diiwaangashno.
Fadlan fiiri hadii aad rabto in aad sameeyso/wax ka bedesho boggaan.',
'userpage-userdoesnotexist-view' => 'Isticmaalahaan  "$1" ma diiwaangashno.',
'blocked-notice-logextract' => 'Isticmaalahaan hadda waa la mamnuucay.
Mamnuucida ugu danbeyso in oo soo galo hoostaan ee ku qorantahay',
'usercssyoucanpreview' => "'''Ogeysiis:''' Isticmaal batoonka \"{{int:showpreview}}\" si aad u baroobeeso CSS'gaaga cusub intii aadan kaydin.",
'userjsyoucanpreview' => "'''Ogeysiis:''' Isticmaal batoonka \"{{int:showpreview}}\" si aad u baroobeeso JavaScriptigaaga cusub intii aadan kaydin.",
'userjspreview' => "'''Waa in aad ogaataa waxaa baroobeynoosaa/fiirinoysaa kaliya JavaScript'ka isticmaalahaaga.'''
'''wali lama keydin!'''",
'updated' => '(waa la opdate gareeyay)',
'note' => "'''fiiro gaar ah:'''",
'previewnote' => "'''Ogaaw kan waa horfiirin oo kaliya.'''
Bedelyadaada wali lama keydin!",
'session_fail_preview' => "'''Waan ka xunahay! Wixii aad bedeshay ma'suurto galin in la'keydiyo cilad dhacday awgeed.
Fadlan markale isku day. Hadii aysan weli shaqaynin, ka bax ee markale soo gudagal.'''",
'session_fail_preview_html' => "'''Waan ka xunahay! Wixii aad bedeshay ma'suurto galin in la'keydiyo cilad dhacday awgeed.'''

''Sababtoo ah {{SITENAME}}han wuxuu leeyahay HTML ceyriin ah, horfiirintiisa waxaa loo qariyey si looga hortago weerar ka yimaada JavaScriptga.''

'''Hadii wax ka bedlkaan uu yahay mid xaq ah, fadlan markale isku day. Hadii aysan weli shaqaynin, is kuday inaad  ka baxdo ee markale soo gudagal.'''",
'editing' => 'Waxaad badalaysaa $1',
'creating' => 'Sameyta $1',
'editingsection' => 'Waxaad wax ka bedelaysaa $1 (qeyb yar)',
'editingcomment' => 'Waxaad wax ka bedelaysaa $1 (qeyb yar)',
'editconflict' => 'Isku dhac badalaadka: $1',
'yourtext' => 'Qoraalkaaga',
'editingold' => "'''DIGNIIN: Waxaad wax ka bedeli rabtaa boggan caddadkiisa duqoobay.
Hadii aad keydisid, waxaa dhumidoona caddadyadii kan ka dambeeyey.'''",
'yourdiff' => 'Kala duwanaanshaha',
'protectedpagewarning' => "'''Digniin: Boggaan waa la difaacay si ee isticmaalada heesto maamulnimada kaliya wax uuga badalaan'''
Fariinta gudagalihii ugu danbeeyay hoostaan ee ku qorontahay:",
'semiprotectedpagewarning' => "'''Fiiro gaar ah:''' Boggaan waa la difaacay si ee isticmaalada isdiiwaan geliyay kaliya wax uuga badalaan.
Fariinta gudagalihii ugu danbeeyay hoostaan ee ku qorontahay:",
'cascadeprotectedwarning' => "'''Digniin:''' Boggaan waa la difaacay si ee maamulada kaliya wax uuga badalaan, sababtoo ah waxaa ku jirto kaskadyadaan la difaacay oo soo sosocoto {{PLURAL:$1|bog|boggaga}}:",
'templatesused' => '{{PLURAL:$1|Tusmo|Tusmooyinka}} lagu isticmaalay boggaan:',
'template-protected' => '(la difaacay)',
'template-semiprotected' => '(difaaca-fudud)',
'hiddencategories' => 'Boggaan wuxuu ka mid yahay {{PLURAL:$1|1 qeyb oo qarsoon|$1 oo ah qeybaha qarsoon}}:',
'nocreate-loggedin' => 'Ma laguu ogolo in aad sameyso boggag cusub.',
'permissionserrors' => 'Cillado ogolaashada ah',
'permissionserrorstext' => 'Ma laguu ogolo in aa taas sameysid,{{PLURAL:$1|sababtaan|sababahaan}} soo socota:',
'permissionserrorstext-withaction' => 'Ma laguu ogolo in aad $2, ku sameysid  {{PLURAL:$1| sababtaan|sababahaan }} soo socota:',
'recreate-moveddeleted-warn' => "'''Digniin: waxaa dib u sameyn rabtaa bog mar hore la tirtiray.'''

Waa in aad dib uuga fikirtaa in ee habboontahay sii socoshada wax looga badalaayo boggaan.
Tirtiraha iyo wareejinta gudagalaha boggaan waxaad ka arki kartaa meeshaan:",
'moveddeleted-notice' => 'Boggaan waa la tirtiray.
Tirtiraha iyo wareejinta gudagalaha boggaan waxaad ka arki kartaa hoostaan.',
'edit-conflict' => 'Wax bedel isku dhacay',
'edit-already-exists' => 'Bog cusub lama samayn karo, wuu jiraa bogaan.',

# Parser/template warnings
'post-expand-template-inclusion-warning' => "'''Digniin:''' Aad oo u weyn yahay tusmo'da aad ku dartay.
Tusmooyinka qaar lagumo dari doono.",
'post-expand-template-inclusion-category' => "Boggaga ku xad gudbay weyninka tusmo'da",
'post-expand-template-argument-warning' => "'''Digniin:'''Boggaan waxaa ku jira ugu yaraan hal iyo wixii ka badan oo template ah, waxaana ku xiran kuwa kale.",

# "Undo" feature
'undo-summary' => 'Noqay bedelaadka $1 ee sameeyay  [[Special:Contributions/$2|$2]] ([[User talk:$2|hadal]])',

# Account creation failure
'cantcreateaccounttitle' => "Ma' sameynkaro gudagal (akoon)",
'cantcreateaccount-text' => "Akoon'ka sameeyaha leh ciwaankaan  IP:ka ('''$1''') waxaa mamnuucay [[User:$3|$3]].

Sababta uu qoray $3 waa ''$2''",

# History pages
'viewpagelogs' => 'Fiiri guadagalayaasha boggaan',
'nohistory' => 'Boggaan malahan taariikhda bedelaadka',
'currentrev' => 'Bedelkii ugu danbeeyay',
'currentrev-asof' => 'Kala duwanaanshihii ugu danbeeyay oo dhacay $1',
'revisionasof' => 'Bedelaadkkii ahaa $1',
'revision-info' => 'Bedelyadii ahaa $1 ee $2',
'previousrevision' => '←Bedelyada ka duqsan',
'nextrevision' => 'Bedelyada ka cusub→',
'currentrevisionlink' => 'Bedelkii ugu danbeeyay',
'cur' => 'kan hadda',
'next' => 'ku xiga',
'last' => 'Ugu dambeeyo',
'page_first' => 'kan ugu horeeyo',
'page_last' => 'Kan ugu dambeeyo',
'histlegend' => "Xarafka Duwanaan : wuxuu isku fiirinaa bedelaadyada kadib neh riix soco ama batoonka kuyaalo hoosta.<br />
Micnaha: '''({{int:cur}})''' = kala duwanaanshaha maqaaladii ugu danbeeyay, '''({{int:last}})''' = kala duwanaanshaha maqaaladii ka horeeyay, '''{{int:minoreditletter}}''' = bedelada yar.",
'history-fieldset-title' => 'Soo raadi taariikhda',
'history-show-deleted' => 'la tirtiray kaliya',
'histfirst' => 'Ugu dhawaa',
'histlast' => 'Ugu cusb',
'historyempty' => '(ebar)',

# Revision feed
'history-feed-title' => 'Taariikhda bedelyada',
'history-feed-empty' => 'Beyjka aad dooneyso majiro.
Waxaa lagayaabaa in laga tirtiray wikigan, ama magacii laga badalay.
Iskuday in aad [[Special:Search|ka raadiso wikigaan]]  Beyjajka la heli karo oo cusub.',

# Revision deletion
'rev-deleted-user' => '(magaca isticmaalaha waa laga saaray)',
'rev-deleted-text-permission' => "Boggaan waa la  '''tirtiray'''.
sababteeda neh waxaa laga heli kartaa  [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} qeybta tirtirda].",
'rev-delundel' => "i'tus/qari",
'rev-showdeleted' => 'Itusi',
'revdelete-show-file-submit' => 'Haa',
'revdelete-radio-same' => '(waxba haka bedelin)',
'revdelete-radio-set' => 'Haa',
'revdelete-radio-unset' => 'Maya',
'revdelete-log' => 'Sababta:',
'revdel-restore' => 'badal muuqaalka',
'revdel-restore-deleted' => 'kuwii la tirtiray badalyadooda',
'revdel-restore-visible' => 'bedelyadka la arki karo',
'pagehist' => 'Taariikhda bogga',
'revdelete-reasonotherlist' => 'sabababaha kale',

# History merging
'mergehistory-from' => 'Xogta bogga:',
'mergehistory-reason' => 'Sabab:',

# Diffs
'history-title' => 'Taariikhda badalka "$1"',
'lineno' => 'Safka $1:',
'compareselectedversions' => 'Is barbardhig bedelyada aad dooratay',
'showhideselectedversions' => 'Itusi/qari bedelaadyada aad dooratay',
'editundo' => 'ka noqo',

# Search results
'searchresults' => 'Natiijada raadinta (Baaris)',
'searchresults-title' => 'Raadinta natiijooyinka "$1"',
'searchsubtitle' => 'Waxaad raadisay \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|dhamaan bogaaga ka bilaawdo "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|dhamaan bogagga la xiriiro "$1"]])',
'searchsubtitleinvalid' => "Waxaa raadisay '''$1'''",
'prevn' => 'Ka horeeya {{PLURAL:$1|$1}}',
'nextn' => 'Ku xiga {{PLURAL:$1|$1}}',
'prevn-title' => 'ka horeeyay  $1 {{PLURAL:$1|natiijo|natiijooyinka}}',
'nextn-title' => 'Kan ku xiga $1 {{PLURAL:$1|natiijo|natiijooyinka}}',
'shown-title' => 'Itusi $1 {{PLURAL:$1|natiijo|natiijooyinka}} halkii bog',
'viewprevnext' => 'Fiiri ($1 {{int:pipe-separator}} $2) ($3).',
'searchmenu-legend' => 'Raadi doorashooyinka',
'searchmenu-exists' => "'''Wikigaan wuu ku jiraa bog la dhoho  \"[[:\$1]]\" .'''",
'searchmenu-new' => "'''Ku sameey bogga  \"[[:\$1]]\" wikigaan!'''",
'searchprofile-articles' => 'Maqaalada kooban',
'searchprofile-project' => 'Caawin iyo Bogga mashruuca',
'searchprofile-images' => 'Multimedia-ha',
'searchprofile-everything' => 'Wax kasto',
'searchprofile-advanced' => 'La talin',
'searchprofile-articles-tooltip' => 'Ka raadi $1',
'searchprofile-project-tooltip' => 'Ka raadi $1',
'searchprofile-images-tooltip' => 'Raadi faylyada',
'searchprofile-everything-tooltip' => 'Raadi wax kasto oo kooban ( xattaa bogga wadahadalka)',
'searchprofile-advanced-tooltip' => 'Ka raadi qeybta isticmaalada',
'search-result-size' => '$1 ({{PLURAL:$2|1 eray|$2 erayo}})',
'search-result-category-size' => '{{PLURAL:$1|1 ka mid ah|$1 ka mid ah}} ({{PLURAL:$2|1 qeybta hoose|$2 qeybaha hoose}}, {{PLURAL:$3|1 fayl|$3 fayl-yo}})',
'search-redirect' => '(waxaa loo toosiyay $1)',
'search-section' => '(maqaalka $1)',
'search-suggest' => 'Ma waxaad ulajeeday: $1',
'search-interwiki-caption' => 'Mashaariicda walaalaha',
'search-interwiki-default' => '$1 natiijooyinka:',
'search-interwiki-more' => '(wax kale)',
'search-relatedarticle' => 'La xiriiro',
'searchrelated' => 'La xiriiro',
'searchall' => 'Dhamaan',
'showingresults' => "Waxaa hoos laga heley{{PLURAL:$1|'''1''' natiijo|'''$1''' natiijooyin}} ka biloow #'''$2'''.",
'showingresultsnum' => "Hoos waxaa laga helay {{PLURAL:$3|'''1''' Natiijo|'''$3''' Natiijooyin}} Ka billow #'''$2'''.",
'showingresultsheader' => "{{PLURAL:$5|Natiijada  '''$1''' ee '''$3'''|Natiijooyinka '''$1 - $2'''  oo ah  '''$3'''}} ee '''$4'''",
'search-nonefound' => 'Wax natiijo oo ka soo baxay ma jirto wixii aad raadisay',
'powersearch' => 'Sidii aad wax uugu raadin laheed',
'powersearch-legend' => 'Sidii aad wax uugu raadin laheed',
'powersearch-ns' => 'ka raadi xarun magaceedka:',
'powersearch-redir' => 'liiska inta la sii toosiyay',
'powersearch-field' => 'Raadi',
'powersearch-togglelabel' => 'Fiiri',
'powersearch-toggleall' => 'Dhamaan',
'powersearch-togglenone' => 'Waxna',

# Preferences page
'preferences' => 'Dooqyada',
'mypreferences' => 'Dooqyadeyda',
'prefsnologin' => 'Gudaha kuma jirtid',
'prefsnologintext' => 'Waa in aad <span class="plainlinks">[{{fullurl:{{#Special:UserLogin}}|returnto=$1}} Gudaha ku jirtaa]</span> si aad dooqyadaada u dalbatid.',
'prefs-skin' => 'Jirka',
'skin-preview' => 'Horfiirin',
'datedefault' => "Ma'jiro dooq",
'prefs-datetime' => 'Taariikhda iyo waqtiga',
'prefs-rc' => 'Isbedelada dhow',
'prefs-watchlist' => 'liiska-waardiyaha',
'prefs-watchlist-days' => 'Tirada maalamaha ay ku jirayaan liiska-waardiyaha:',
'prefs-email' => 'E-mail aad dooran kartaa',
'saveprefs' => 'Kaydi',
'prefs-editing' => 'Wax ka bedelka',
'searchresultshead' => 'Raadi',
'recentchangesdays' => 'Tirada maalmaha lagu tusaayo isbedelada dhow:',
'savedprefs' => 'Dooqyadaada waa la keydiyey.',
'timezonelegend' => 'Soonaha waqtiga:',
'localtime' => 'Waqtigaaga',
'timezoneregion-africa' => 'Afrika',
'timezoneregion-america' => 'Ameerika',
'timezoneregion-antarctica' => 'Antiarktis',
'timezoneregion-arctic' => 'Arktik',
'timezoneregion-asia' => 'Aasiya',
'timezoneregion-atlantic' => 'Badweynta Atlaantik',
'allowemail' => 'Ogolow in e-mail ay kaagatimaado isticmaalayaasha kale',
'prefs-searchoptions' => 'Dooqyada raadinta',
'youremail' => 'E-mail:',
'username' => 'Gudagal:',
'uid' => 'Lambarka isticmaalaha:',
'yourrealname' => 'Magacaaga runta ah:',
'yourlanguage' => 'luqad:',
'yournick' => 'Saxiix cusub:',
'badsiglength' => 'Naaneysta aad bey u dheertahay.
Waa in aysan ka badanin $1 {{PLURAL:$1|eray|erayo}}.',
'yourgender' => 'Jinsi:',
'gender-unknown' => 'Aana la qeexin',
'gender-male' => 'Lab',
'gender-female' => 'Dhedig',
'email' => 'E-mail',
'prefs-help-realname' => 'Optional: if you choose to provide it this will be used for giving you attribution for your work.',
'prefs-help-email' => 'E-mail waa wax aad xor u leedahay. laakiin waa loo baahanyahay hadii aad eraysirka badaleesid, hadii aad ilaawdo eraygaaga sirta ah',
'prefs-help-email-others' => 'Waxaa kale oo aad u isticmaali kartaa in ee dadka kale kugula soo xiriiraan e-mail ayaga oo isticmaalaayo linki isticmaalahaada ama bogga wadahadalka.
E-mailkaada mala sheegaayo markii ee dadka kale kula soo xiriirayaan.',
'prefs-help-email-required' => 'Waxaa loo baahanyahay e-mail.',

# User rights
'saveusergroups' => 'Kaydi kooxaha isticmaalayaasha',
'userrights-groupsmember' => 'Ka mid ah:',
'userrights-reason' => 'Sababta:',

# Groups
'group' => 'Koox:',
'group-user' => 'Isticmaalada',
'group-autoconfirmed' => 'Gude galayaasha la hubiyey si iskeed ah',
'group-bot' => 'botyada',
'group-sysop' => 'Maamulada',
'group-all' => '(dhamaan)',

'group-user-member' => '{{GENDER:$1|isticmaale}}',
'group-bot-member' => '{{GENDER:$1|bot}}',
'group-sysop-member' => '{{GENDER:$1|maamulaha}}',

'grouppage-user' => '{{ns:project}}:Isticmaalada',
'grouppage-autoconfirmed' => '{{ns:project}}:Adeegsade la hubiyey',
'grouppage-sysop' => '{{ns:project}}:Maamulada',

# Rights
'right-read' => 'Akhri maqaalada',
'right-edit' => 'Wax ka bedel bogyaalo',
'right-move' => 'Wareeji maqaalada',
'right-upload' => 'Soo geli fayl',
'right-delete' => 'Tirtir maqaalada',
'right-bigdelete' => 'Tirtir maqaalada taariikhda dheer leh',
'right-browsearchive' => 'Raadi maqaalada la tirtiray',
'right-undelete' => 'Ha tirtirin bog',

# Special:Log/newusers
'newuserlogpage' => 'Gudagalaha Isticmaale sameeyay',

# Associated actions - in the sentence "You do not have permission to X"
'action-read' => 'akhri boggaan',
'action-edit' => 'wax ka bedel boggaan',
'action-createpage' => 'sameey bogyaalo',
'action-upload' => "soo geli file'kaan",
'action-delete' => 'tirtir boggaan',
'action-browsearchive' => 'Raadi maqaalada la tirtiray',
'action-undelete' => 'ha tirtirin boggaan',
'action-block' => 'ka mamnuuc isticmaalahaan in oo wax badalo',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|bedelka|bedelada}}',
'recentchanges' => 'Isbedelada dhow',
'recentchanges-legend' => 'Dooqyada isbedelada dhow',
'recentchanges-summary' => 'Dabagal isbedelada dhow ee wikiga ee ku dhacay bogaan.',
'recentchanges-noresult' => 'Ma jiraan wax is bedel ah xilliga aad soo koobtay ee u dhigma habkaan.',
'recentchanges-feed-description' => 'Dabagal isbedelada dhow ee wikiga oo ku dhacay feedkaan',
'recentchanges-label-newpage' => 'Wax bedelkaan wuxuu sameeyay bog cusub',
'recentchanges-label-minor' => 'Kan waa bedel yar',
'recentchanges-label-bot' => 'Badalkaan waxaa sameeyay bot',
'recentchanges-label-unpatrolled' => 'bedelkaan hadda wali lama waardiyeen',
'rcnote' => "Hoostaan  {{PLURAL:$1|waa '''1''' badalkii| '''$1''' ee ugu danbeeyay}} oo dhacay wixii ka danbeeyay {{PLURAL:$2|maalin|'''$2''' maalmood}}, marka ee eheed $5, $4.",
'rcnotefrom' => "Hoostaan waa isbedaladii dhacay  '''$2''' (waxaad arkoosaa ilaa '''$1''' ).",
'rclistfrom' => 'Itusi isbedelada cusub oo ka bilaabaneyso $1',
'rcshowhideminor' => '$1 bedelada yar',
'rcshowhidebots' => '$1 botyaalo',
'rcshowhideliu' => '$1 isticmaalada-soo galay',
'rcshowhideanons' => '$1 isticmaalada la aqoon',
'rcshowhidepatr' => '$1 bedelada la waardiyeeyay',
'rcshowhidemine' => '$1 wax badalkeyga',
'rclinks' => 'Itusi isbadeladii  $1 ee ugu danbeeyay oo dhacay wixii ka danbeeyay $2 maalmood<br />$3',
'diff' => 'duwanaan',
'hist' => 'taariikh',
'hide' => 'Qari',
'show' => 'Itus',
'minoreditletter' => 'y',
'newpageletter' => 'C',
'boteditletter' => 'b',
'rc_categories' => 'Wuxuu u gaar yahay qeybaha  (u kala qeybsan "|")',
'rc-enhanced-expand' => 'Itus ka hadalka (waxaa loo baahanyahay JavaScript)',
'rc-enhanced-hide' => 'Qari ka hadalka',

# Recent changes linked
'recentchangeslinked' => "Isbedelada la'xiriira",
'recentchangeslinked-toolbox' => "Isbedelada la'xiriira",
'recentchangeslinked-title' => 'Wax bedelka la xiriiro "$1"',
'recentchangeslinked-summary' => "Liiskaan waa badalyada mardhow lagu sameeyay bogyaasha la xiriiray boggaga khaaska ah  (ama ka mid ahaa qeybaha khaaska ah).
Boggaga ku jiro  [[Special:Watchlist|liiskaaga waardiyaha]] waa '''butac'''.",
'recentchangeslinked-page' => 'Magaca bogga:',
'recentchangeslinked-to' => 'Itusi isbedelada boggaga la xiriiro bogga aan ku siiyay',

# Upload
'upload' => 'Soo geli file',
'uploadbtn' => 'Soo geli file',
'uploadnologin' => 'Gudaha kuma jirtid',
'uploaderror' => 'Qalad soo gelinta',
'upload-permitted' => 'Nuucyada faylasha la ogolyahay: $1.',
'uploadlog' => 'gudagalaha soo galiyay',
'uploadlogpage' => 'Gudagalaha soo galiyay',
'filename' => 'Magaca faylka',
'filedesc' => 'Qoraal kooban',
'filestatus' => 'Qaabka ogolaashada koobiga:',
'ignorewarning' => 'Iska dhagooleey digniinta faylka neh  keydi',
'ignorewarnings' => 'Iska dhagooley digniin walba',
'minlength1' => 'Faylka magaciisa waa in uu ugu yaraan noqdaa hal xaraf.',
'badfilename' => 'Faylka magaciisa waxaa lagu badalay "$1".',
'filetype-banned' => 'Faylka nuucaan waa laga mamnuucay',
'illegal-filename' => "Magaca file'kaan lama ogola",
'unknown-error' => 'Qalad la aqoon aa dhacay.',
'tmp-create-error' => 'Mala sameyn karin fayl kumeel gaar ah.',
'large-file' => "waxaa loo baahanyahay in ay san file'yada ka weynaan $1;
file'kaan waa  $2.",
'uploadwarning' => 'Digniin waxa aad soo gelineesid',
'savefile' => 'Faylka kaydi',
'uploadedimage' => 'la soo galiyay "[[$1]]"',
'overwroteimage' => 'waxaa la soo galiyay nuuc cusub oo ah "[[$1]]"',
'uploaddisabled' => 'wax soo gelinta waa la xiray.',
'copyuploaddisabled' => 'wax soo gelinta dhinaca URL:ka waa la xiray',
'uploadfromurl-queued' => 'Waxa aad soo gelineesid saf oo galay.',
'uploaddisabledtext' => 'soo gelinta faylyada waa la xiray',
'uploadvirus' => 'faylka waxaa ku jiro fayrus!
ku saabsan: $1',
'upload-source' => 'Asalka fileka',
'destfilename' => 'Magaca faylka la doonayo',
'upload-maxfilesize' => 'Ugu badnaan cabirka faylka: $1',
'upload-description' => 'Qeexida faylka',
'upload-options' => 'Dooqyada soo gelinta',
'watchthisupload' => 'Faylkaan waardiyeey',
'upload-failure-subj' => 'Dhibaatada soo gelinta',
'upload-warning-subj' => 'Digniin waxa aad soo gelineesid',

'upload-unknown-size' => 'lama yaqaano weyninka',

# img_auth script messages
'img-auth-streaming' => 'Woo dareeraa "$1".',

# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
'upload-curl-error28' => 'Waqtiga woo ka dhamaaday soo gelinta',

'license' => 'Laysinka:',
'license-header' => 'Laysinka',
'nolicense' => 'Mala dooran',
'license-nopreview' => '(Hor fiirin malahan)',
'upload_source_file' => '(Faylka kombiyutarkaada)',

# Special:ListFiles
'listfiles_search_for' => 'Raadi magacyada wararka:',

# File description page
'file-anchor-link' => 'Fayl',
'filehist' => 'Taariikhda faylka',
'filehist-help' => 'Riix taariikhda/waqtiga si aad u argto faylka sida oo ahaa markiisa hore.',
'filehist-deleteall' => 'tirtir dhamaan',
'filehist-deleteone' => 'tirtir',
'filehist-revert' => 'celi',
'filehist-current' => 'kan hadda',
'filehist-datetime' => 'Taariikhda/Waqtiga',
'filehist-thumb' => 'Sawir yar',
'filehist-thumbtext' => 'Sawirka yar nuuciisa ahaa $1',
'filehist-user' => 'Isticmaale',
'filehist-dimensions' => 'Cabirka',
'filehist-comment' => 'Ka hadalka',
'imagelinks' => 'Faylka lagu isticmaalay',
'linkstoimage' => 'Boggagaan soo socota ee  {{PLURAL:$1|ah waxey la xiriiraan|$1 ah waxey la xiriiraan}} faylkan:',
'nolinkstoimage' => "Ma'ay jiraan beyjaj ku xiran faylkaan.",
'sharedupload-desc-here' => 'Faylkaan wuxuu ka socdaa  $1 waxaana laga yaabaa in lagu isticmaalay mashruucyada kale.
Tafaasiishiisa waxee ku qorantahay [$2 bogga tafaasiisha faylka] oo ka arki kartid hoostaan.',

# File reversion
'filerevert-comment' => 'Sababta:',

# File deletion
'filedelete' => 'Tirtir $1',
'filedelete-legend' => 'Tirtir fayl',
'filedelete-intro' => "Waxaad tirtiri rabtaa faylka '''[[Media:$1|$1]]''' iyo dhamaan taariikhdiisa.",
'filedelete-comment' => 'Sababta:',
'filedelete-submit' => 'Tirtir',
'filedelete-success' => "'''$1''' waa la tirtiray.",
'filedelete-reason-otherlist' => 'sababaha kale',
'filedelete-edit-reasonlist' => 'Wax ka bedel sababta loo tirtiray',

# MIME search
'mimesearch' => 'MIME  raadi',

# Random page
'randompage' => 'Ku nasiibso bog',

'brokenredirects-edit' => 'wax ka bedel',
'brokenredirects-delete' => 'tirtir',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|bayt|bayt}}',
'nmembers' => ' $1 {{PLURAL:$1|ka mid ah|ka mid ah}}',
'lonelypages' => 'Boggaga agoonta ah',
'uncategorizedpages' => 'Maqaalada aan la aruurin',
'popularpages' => 'Boggaga caanka ah',
'prefixindex' => 'Dhamaan bogagga leh qoraalka hore',
'shortpages' => 'Boggaga gaaban',
'longpages' => 'Boggaga dhaadheer',
'deadendpages' => 'Boggaga aanan la daba joogin',
'deadendpagestext' => 'Boggagaan soo socota lama xiriiraan boggaga kale ee {{SITENAME}}.',
'protectedpages' => "Boggag la'difaacay",
'listusers-editsonly' => 'Itus adeegsede yaasha sameeyey bedalka oo kaliya',
'listusers-creationsort' => 'Ka dhig si ah taariikhdii la sameeyey',
'usercreated' => '{{GENDER:$3|Sameeyay}} marka ee eheed $1 saacada $2',
'newpages' => 'Bogyaalo cusub',
'newpages-username' => 'Magaca gudagalka:',
'ancientpages' => 'Boggaga duqoobay',
'move' => 'Wareeji',
'pager-newer-n' => '{{PLURAL:$1|ka cusub 1|ka cusub $1}}',
'pager-older-n' => '{{PLURAL:$1|ka duqsan 1|ka duqsan $1}}',

# Book sources
'booksources' => 'Xogta buuga',
'booksources-search-legend' => 'Raadi xogta buuga',
'booksources-go' => 'Soco',

# Special:Log
'log' => 'Guda galayaasha',

# Special:AllPages
'allpages' => 'Dhamaan bogagga',
'alphaindexline' => '$1 ilaa $2',
'nextpage' => 'Bogga ku xiga ($1)',
'prevpage' => 'Bogga ka horeeyo ($1)',
'allpagesfrom' => 'Soosaar boggaga ka bilaawda:',
'allarticles' => 'Dhamaan bogagga',
'allinnamespace' => 'Dhamaan bogagga ($1 namespace)',
'allnotinnamespace' => 'Dhamaan bogagga (aan ku jirin xarun magaceedka $1)',
'allpagesprev' => 'ka hore',
'allpagesnext' => 'Ku xiga',
'allpagessubmit' => 'Soco',
'allpagesprefix' => 'Soo saar boggaga leh horgalaha:',
'allpagesbadtitle' => "Cinwaanka bogga xaq ma'aha ama waa ereyo u gaar ah isdhaafka-luqadaha ama isdhaafka-wiki. Waxaa ku jirikara xuruufo aanan loo isticmaalikarin cinwaan ahaan.",

# Special:Categories
'categories' => 'Qeybaha',
'special-categories-sort-count' => 'xisaabi marka aad tirisid',

# Special:LinkSearch
'linksearch-ns' => 'Xarun magaceedka:',
'linksearch-ok' => 'Raadi',
'linksearch-line' => '$1 wuxuu ka socdaa $2',

# Special:ListUsers
'listusersfrom' => "I'tus isticmaalayaasha laga bilaabo:",
'listusers-submit' => "I'tus",
'listusers-noresult' => 'Lama helin isticmaale.',
'listusers-blocked' => '(waa la mamnuucay)',

# Special:ListGroupRights
'listgrouprights-members' => '(Inta ka mid ah liiskooda)',

# Email user
'mailnologin' => "Ma'jiro cinwaan wax lagu diro",
'mailnologintext' => 'Waa in aad [[Special:UserLogin|gudaha ku jirtaa]]
kuna haysatid E-boosto sax ah [[Special:Preferences|dooqyadaada]],
si aad ugu dirto E-boosto isticmaalayaasha kale.',
'emailuser' => 'E-mail u dir isticmaalahaan',
'emailpage' => 'Isticmaalaha e-mailka',
'noemailtitle' => 'Malahan cinwaan E-mail',
'emailfrom' => 'Ka socoto:',
'emailto' => 'Ku:',
'emailsubject' => 'Arinta:',
'emailmessage' => 'Fariinta:',
'emailsend' => 'Dir',
'emailccme' => 'E-mail iigu soo dir fariinteyda oo koobi ah.',
'emailsent' => 'E-mailka waa la diray',
'emailsenttext' => 'Fariintaadii E-mailka aheeyd waa la diray.',

# Watchlist
'watchlist' => 'Liiskeyga waardiyeynta',
'mywatchlist' => 'Liiskeyga waardiyeynta',
'watchlistfor2' => 'Ku socoto $1 $2',
'nowatchlist' => 'Waxba kuma jiraan liiskaaga waardiyeynta.',
'watchlistanontext' => 'Fadlan $1 si aad u fiirisid ama wax uga bedeshid qoraalada ku jira liiska waardiyeyska.',
'watchnologin' => 'Gudaha kuma jirtid',
'watchnologintext' => 'Waa ina aad [[Special:UserLogin|gudaha ku jirtaa]] si aad wax uga bedeshid liiskaaga waardiyeynta.',
'addedwatchtext' => "Bogga \"[[:\$1]]\" waxaa lagudaray [[Special:Watchlist|liiska-waardiyahaaga]].
Isbedelka mustaqbalka ku dhaca boggan iyo bogga wadahadalka la'xiriira waxaa lagu soo qoridoonaa inta,
boggana wuxuu noqonaayaa mid la' '''nuuriyey''' dhinaca [[Special:RecentChanges|Liiska isbedelada show]] si
ay u fududdayso sidii loo dalbanlahaa.

Hadii aad rabootid in aad boggan ka saartid wardiyeynta, dhagsii \"Ha' wardiyeynin\" oo ku yaala dhinaca.",
'removedwatchtext' => 'Bogga "[[:$1]]" waa laga saaray [[Special:Watchlist|liiskaaga waardiyaha]].',
'watch' => 'Waardiyey',
'watchthispage' => 'Boggaan waardiyeey',
'unwatch' => 'Ha waardiyeynin',
'unwatchthispage' => 'Jooji waardiyeyntiisa',
'watchlist-details' => '{{PLURAL:$1|$1 bog|$1 boggag ah}}  aa ku jirto liiskaaga waardiyaha, ma lagu darin boggaga wadahadalka.',
'watchlistcontains' => 'Liiskaaga waardiyeynta waxaa ku jiro $1 {{PLURAL:$1|bog|boggag}}.',
'wlshowlast' => 'Itus wixii ka danbeeyay $1 saacadood $2 maalmood $3',
'watchlist-options' => 'Dooqyada liiska waardiyaha',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Daawasho...',

'enotif_subject_created' => '{{SITENAME}} Bogga $1 Qof ayaa sameeyey {{gender:$2|$2}}',
'enotif_subject_changed' => '{{SITENAME}} Bogga $1 Waxaa {{GENDER:$2|Bedel}} ku sameeyey qof $2',
'enotif_body_intro_created' => 'Bogga {{SITENAME}} ga $1 waxaa la sameeyey $PAGEEDITDATE qof {{gender:$2|$2}}, eeg $3 sida laga dhigay hadda.',
'enotif_body_intro_moved' => 'Bogga {{SITENAME}} $1 {{GENDER:$2|move|loo wareejiyey}} $2 ee $PAGEEDITDATE. si aad u aragto sida uu yahay hadda eeg $3.',
'enotif_body_intro_restored' => 'Booga {{SITENAME}} $1 waa labadelay {{GENDER:$2|dib u habayn}} waqtigaan $PAGEEDITDATE waxaana badalay $2, eeg $3 sida hadda laga dhigay.',
'enotif_body_intro_changed' => 'Bogga {{SITENAME}} ga $1 waxaa la badelay $PAGEEDITDATE qof {{gender:$2|$2}}, eeg $3 sida laga dhigay hadda.',
'enotif_lastvisited' => 'Eeg $1 Dhamaan isbedeleda ilaa goortii kuugu dambaysay.',
'enotif_lastdiff' => 'Eeg $1 si aad u aragto bedelkaan.',
'enotif_anon_editor' => 'Aan la qoon $1',
'enotif_body' => 'Mudane $WATCHINGUSERNAME,

$PAGEINTRO $NEWPAGE

Qaybta wax laga bedelay: $PAGESUMMARY $PAGEMINOREDIT

La xariirka Tifaftiraha:
mail: $PAGEEDITOR_EMAIL
wiki: $PAGEEDITOR_WIKI

Lama soo diri doono ogeysiin dambe hadii isbedel kale lagu sii sameeyo ilaa aad ka soo booqato bogga.
Waxaad awoodaa inaad ka saarto liiska waardiyeha bogga.

			 Nidaamka war gelinta {{SITENAME}} ee E-mailka

--
si aad ubedesho fariinta e-mail dooqyadiisa, Booqo
{{canonicalurl:{{#special:Preferences}}}}

Si aad ubedesho liiskaada waardiyaha, Booqo
{{canonicalurl:{{#special:EditWatchlist}}}}

si aad utirtirto liiskaada waardiyaha ee gaarka ah, Booqo
$UNWATCHURL

Faalada iyo helista caawinaad dheeraad ah:
{{canonicalurl:{{MediaWiki:Helppage}}}}',

# Delete
'confirm' => 'Xaqiiji',
'excontent' => "qoraalka wuxuu ahaa: '$1'",
'exbeforeblank' => 'Intii la masaxin waxaa ku qornaa: "$1"',
'exblank' => 'Bogga waxba kuma jirin',
'delete-confirm' => 'Tirtir "$1"',
'delete-legend' => 'Tirtir',
'historywarning' => "'''Digniin:''' Bogga aad tirtiri rabtid wuxuu leeyahay taariikh lagu qiyaaso $1 {{PLURAL:$1|bedelyo ah|bedelaadyo ah}}:",
'actioncomplete' => "Amarka waa la'dhamaystiray",
'actionfailed' => 'Shaqada waad ku guul dareesatay',
'dellogpage' => 'Tirtiraha guda galaheeda',

# Rollback
'rollback_short' => 'Soo celi',
'rollbacklink' => 'dib u soo celi',
'rollbacklinkcount-morethan' => 'soo celinta in kabadan $1 {{PLURAL:$1|badal|badallo}}',
'revertpage' => 'Wuxuu dib u noqay badalkii oo sameeyay  [[Special:Contributions/$2|$2]] ([[User talk:$2|talk]]) kuna celiyay badalkii ka  danbeeyay oo sameeyay  [[User:$1|$1]]',
'revertpage-nouser' => 'Wuxuu dib u noqay bedelyada (magaca isticmaalaha waa laga saaray) kuna celiyay  [[User:$1|$1]]',
'rollback-success' => 'Wuxuu dib u noqay bedelka oo sameeyay  $1;
Wuxuu ku badalay bedelkii ka danbeeyay oo sameeyay $2.',

# Protect
'protectlogpage' => 'Difaacida gudagalaheeda',
'protectlogtext' => 'Hoos waxaa ku qoran isbedelada ilaaliya bogagga.
eeg [[Special:ProtectedPages|Liiska bogagga dhowrsoon]] liiska bogagga howlaha dhowrista ee hadda.',
'protectedarticle' => 'la difaacay "[[$1]]"',
'modifiedarticleprotection' => 'Ka badal heerka difaacida "[[$1]]"',
'protect-title' => 'Ka badal heerka difaacida   "$1"',
'prot_1movedto2' => '[[$1]] waxaa loo wareejiyey [[$2]]',
'protect-legend' => 'Xaqiiji difaacida',
'protectcomment' => 'Sababta:',
'protectexpiry' => 'wuxuu dhacaa:',
'protect_expiry_invalid' => "Wakhtiga dhicitaanka sax ma'aha.",
'protect_expiry_old' => 'Wakhtiga dhictaanka waa mid laga soo dhaafay.',
'protect-default' => 'U ogolaaw isticmaalada oo dhan',
'protect-fallback' => 'waxaa loo baahanyahay "$1"  ogolaasho',
'protect-level-sysop' => 'Maamulada kaliya',
'protect-expiring' => 'wuxuu dhacaa  $1 (UTC)',
'protect-cascade' => 'Is daba dhiga difaacida - difaac bogga walba oo lagu daro boggaan.',
'protect-othertime' => 'Waqti kale:',
'protect-othertime-op' => 'waqti kale',
'restriction-type' => 'Ogolaasho:',
'restriction-level' => 'Xadka xadidaada:',

# Restrictions (nouns)
'restriction-edit' => 'Wax ka bedel',
'restriction-move' => 'Wareeji',

# Restriction levels
'restriction-level-all' => 'qaab kasto',

# Undelete
'undelete' => "Fiiri boggaga la'tirtiray",
'undeletepage' => "Fiiri dibna u sooceli boggaga la'tirtiray",
'undeletepagetitle' => "'''Meeshaan waxa ay ka koobatahay raadka wixii laga tiray[[:$1|$1]]'''.",
'viewdeletedpage' => "Fiiri boggaga la'tirtiray",
'undeletebtn' => 'Sooceli',
'undeletelink' => 'fiiri/mar kale sameey',
'undeleteviewlink' => 'itusi',
'undeletereset' => 'Dib u habeey',
'undeletedrevisions' => '$1 {{PLURAL:$1|revision|revisions}} restored',
'undeletedrevisions-files' => '$1 {{PLURAL:$1|revision|revisions}} and $2 {{PLURAL:$2|file|files}} restored',
'undeletedfiles' => '$1 {{PLURAL:$1|file|files}} restored',
'cannotundelete' => "Soo celinta ma' suurto galin; waxaa laga yaabaa in qofkale uu horay u soo celyey bogga.",
'undelete-search-box' => 'Raadi bogagga la tirtiray',
'undelete-search-prefix' => "I'tus boggaga ku bilaawda:",
'undelete-search-submit' => 'Raadi',

# Namespace form on various pages
'namespace' => 'Xarun magaceedka:',
'invert' => 'Dabagedi dalabka',
'namespace_association' => 'La xiriira xarun magaceedka',
'blanknamespace' => '(Bogga hore)',

# Contributions
'contributions' => 'Isticmaalada wax ku darsaday',
'contributions-title' => 'Waxa oo ku darsaday isticmaalaha $1',
'mycontris' => 'Wax qoraalkeyga',
'contribsub2' => 'Ku socoto $1 ($2)',
'uctop' => '(kor)',
'month' => 'Bilaawga bisha (iyo wixii ka danbeeyay):',
'year' => 'Bilaawga sanadka  (iyo wixii ka danbeeyay):',

'sp-contributions-newbies' => 'Itus akoonada cusub kaliya oo wax ku darsaday',
'sp-contributions-blocklog' => 'mamnuucyada',
'sp-contributions-uploads' => 'wixii la soo geliyay',
'sp-contributions-logs' => 'Guda galayaasha',
'sp-contributions-talk' => 'Wadahadal',
'sp-contributions-search' => 'Raadi si aad wax uugu darsatid',
'sp-contributions-username' => 'Ciwaanka IP:ga  ama  magaca isticmaalaha:',
'sp-contributions-toponly' => 'itusi kaliya badalyada ah kuwii ugu danbeeyay oo wax laga badalay',
'sp-contributions-submit' => 'Raadi',

# What links here
'whatlinkshere' => 'Maxaa meeshaan la xiriiro',
'whatlinkshere-title' => 'Boggaga la xiriiro "$1"',
'whatlinkshere-page' => 'Bogga:',
'linkshere' => "Bogyaashaan waxey la xiriiraan  '''[[:$1]]''':",
'nolinkshere' => "Boggag la xiriiro   '''[[:$1]]''' ma jirto.",
'isredirect' => 'bogga loo sii toosiyay',
'istemplate' => 'ku jiri kara',
'isimage' => 'faylka la xiriiro',
'whatlinkshere-prev' => '{{PLURAL:$1|kii ka horeeyay|kii ka horeeyay $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|kan ku xiga|kan ku xiga $1}}',
'whatlinkshere-links' => '← kuwa la xiriiro',
'whatlinkshere-hideredirs' => '$1 loo sii toosiyay',
'whatlinkshere-hidelinks' => '$1 wuxuu la xiriiraa',
'whatlinkshere-hideimages' => '$1 sawirka inta oo la xiriiro',

# Block/unblock
'ipboptions' => "2 saacadood:2 hours,1 maalin:1 day,3 maalmood:3 days,1 usbuuc:1 week,2 isbuuc:2 weeks,1 bil:1 month,3 bilood:3 months,6 bilood:6 months,1 sano:1 year,daa'im:infinite",
'ipblocklist' => 'isticmaalada la mamnuucay',
'ipblocklist-submit' => 'Raadi',
'anononlyblock' => 'qarsoon. kaliya',
'blocklink' => 'mamnuuc',
'unblocklink' => 'ka qaad mamnuucida',
'change-blocklink' => 'wax ka bedel mamnuucida',
'contribslink' => 'ku darsasho',
'autoblocker' => 'Waxaa automaatik u xirista keenay in mudo dhow uu cinwaanka IP:ga isticmaalay "[[User:$1|$1]]". Sababta keentay in loo xiro $1 waa: "\'\'\'$2\'\'\'"',
'blocklogpage' => 'Mamnuucida guda galaheeda',
'blocklogentry' => 'la mamnuucay  [[$1]] Waqtiga uu dhacaayo neh waa $2 $3',
'blocklogtext' => 'Halkaan waa  liiska lagu muujiyo manuuca iyo mamnuuc ka qaadista.
Ciwaanka IP ga ee la mamnuucay so iskeedka ee aan la soo ban dhigin.
Eeg [[Special:BlockList|Mamnuucyada]] si aad u aragto liiska mamnuucyada ee hadda shaqaynaua.',
'unblocklogentry' => 'lama mamnuucin $1',
'block-log-flags-anononly' => "Isticmaalayaasha aanan la'aqoonsanin oo kaliya",
'block-log-flags-nocreate' => 'sameynta gudagalah lamaogola',
'block-log-flags-noemail' => 'e-mailka laga mamnuucay',
'ipb-needreblock' => '$1 mar hore aa la mamnuucay. marabtaa in aad wax ka bedesho habka?',

# Move page
'movenologin' => 'Gudaha kuma jirtid',
'movedto' => 'loo wareejiyey',
'movetalk' => "Wareejiyey bogga wadahadalka la'xiriira",
'movelogpage' => 'Wareejinta guda galaheeda',
'revertmove' => 'celi',

# Export
'export' => 'Dhoofi boggag',
'export-addcattext' => 'Ku dar maqaalo laga soo qaaday qeybaha:',
'export-addns' => 'Ku dar',

# Namespace 8 related
'allmessages' => 'Fariimaha sistamka',
'allmessagesname' => 'Magac',
'allmessagesdefault' => "Qoraalka la'isku ogyahay",
'allmessagescurrent' => 'Qoraalka hada qoran',
'allmessagestext' => 'Kan waa liiska fariimaha systemka oo laga heli karo xarun magaceedka MediaWiki.
Fadlan booqo [//www.mediawiki.org/wiki/Localisation MediaWiki Localisation] iyo [//translatewiki.net translatewiki.net] hadii aad rabto in aad wax ku darsatid guud ahaanba MediaWiki ku fasirida luqadaada.',
'allmessagesnotsupportedDB' => "'''{{ns:special}}:Allmessages''' la'ma isticmaalikaro, '''\$wgUseDatabaseMessages''' oo dansan daraadeed.",
'allmessages-language' => 'Luqad:',
'allmessages-filter-submit' => 'Soco',

# Thumbnails
'thumbnail-more' => 'Weyneey',
'thumbnail_error' => 'Qalad sameynta thumbnail: $1',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Boggaaga isticmaalaha',
'tooltip-pt-mytalk' => 'Bogaaga wadahadalka',
'tooltip-pt-preferences' => 'Dooqyadeyda',
'tooltip-pt-watchlist' => 'Liiska bogga aad adiga ka waardiyeeyneyso isbedelada',
'tooltip-pt-mycontris' => 'Liiska intii aad ku darsatay',
'tooltip-pt-login' => 'Waxaa loo baahanyahay in aad gudaha gashid; laakiin,  laasim ma ahan',
'tooltip-pt-logout' => 'Ka bax',
'tooltip-ca-talk' => 'Wadahadal ku saabsan bogga qoraalka',
'tooltip-ca-edit' => 'Boggaan wax waad ka bedelikartaa. Intii aadan kaydinin fadlan isticmaal batoonka horfiirinta.',
'tooltip-ca-addsection' => 'Bilaaw qeyb cusub',
'tooltip-ca-viewsource' => 'Boggaan waa la difaacay.
Waxaa fiiri kartaa cadaadkiisa',
'tooltip-ca-history' => 'Bedelyadii hore ee boggaan.',
'tooltip-ca-protect' => 'Difaac boggaan',
'tooltip-ca-delete' => 'Bogaan tirtir',
'tooltip-ca-undelete' => "Soo celi waxyaabihii laga badalay boggaan intii aanan la'tirtirin",
'tooltip-ca-move' => 'Wareeji boggaan',
'tooltip-ca-watch' => 'Boggaan ku dar liiskaaga waardiyaha',
'tooltip-ca-unwatch' => 'Boggaan ka saar liiskaaga waardiyaha',
'tooltip-search' => 'Ka raadi {{SITENAME}}',
'tooltip-search-go' => 'Aad bog oo magacaan ku qoran hadii oo jiro',
'tooltip-search-fulltext' => 'Qoraalkaan ka raadi bogyaasha',
'tooltip-p-logo' => 'Bogga Hore',
'tooltip-n-mainpage' => 'Soo booqo bogga hore',
'tooltip-n-mainpage-description' => 'Booqo bogga hore',
'tooltip-n-portal' => 'Faahfaahinta mashruuca, waxaad ku caawinkartid, xageed ka helikartaa waxaad u baahantahay',
'tooltip-n-currentevents' => 'Soo raadi war ku saabsan hadda waxa dhacaayo',
'tooltip-n-recentchanges' => 'tirada Intii ugu danbeysay oo wax laga bedelay wiki',
'tooltip-n-randompage' => 'Ku nasiibso bog',
'tooltip-n-help' => 'Meesha lagu ogaan karo',
'tooltip-t-whatlinkshere' => 'Liiska inta bog oo wiki ah oo meeshaan la xiriiro',
'tooltip-t-recentchangeslinked' => 'Isbedelada dhow ee boggaga oo laga soo xiriiriyay boggaan',
'tooltip-feed-atom' => 'Atom aa quudiyo boggaan',
'tooltip-t-contributions' => 'Itusi liiska inta wax oo ku darsaday isticmaalahaan',
'tooltip-t-emailuser' => 'E-mail u dir isticmaalahaan',
'tooltip-t-upload' => 'Soo geli fayl',
'tooltip-t-specialpages' => 'Liiska boggaga qaaska ah oo dhan',
'tooltip-t-print' => 'Nuuca la soo daabici karo ee boggaan',
'tooltip-t-permalink' => 'Linkiga daaimka ah ee  bedelaadka boggaan',
'tooltip-ca-nstab-main' => 'Itusi bogga qoraaka kooban',
'tooltip-ca-nstab-user' => 'Fiiri bogga isticmaalaha',
'tooltip-ca-nstab-media' => 'Fiiri bogga saxaafada',
'tooltip-ca-nstab-special' => 'Kani bogg khaas ah, waxba kama bedelikartid boggaan',
'tooltip-ca-nstab-project' => 'Itusi bogga mashruuca',
'tooltip-ca-nstab-image' => 'Fiiri faylka bogga',
'tooltip-ca-nstab-mediawiki' => 'Fiiri bogga fariimaha sistamka',
'tooltip-ca-nstab-template' => 'Fiiri tusmada',
'tooltip-ca-nstab-help' => 'Fiiri bogga caawinaad',
'tooltip-ca-nstab-category' => 'Itusi qeybta bogga',
'tooltip-minoredit' => 'Calaamadeey kan in oo yahay bedel yar',
'tooltip-save' => 'kaydso badalyadaada',
'tooltip-preview' => 'Feerinta wixii aad bedeshay, fadlan kan isticmaal intii aadan kaydinin!',
'tooltip-diff' => 'Fiiri waxa aad ka badashay qoraalka',
'tooltip-compareselectedversions' => 'Fiiri sida ee u kala duwanyihiin  bedelaadka labada aad ka dooratay boggaan',
'tooltip-watch' => 'Boggaan ku dar liiskaaga waardiyaha',
'tooltip-watchlistedit-raw-submit' => 'Liska waardiyeha dib u howlageli',
'tooltip-rollback' => '"Dib u soo celi" wuxuu dib boggaan ugu soo celinaa qofkii ugu danbeeyay wixii oo ku darsaday hal riix kaliya',
'tooltip-undo' => '"Ka noqo" wuxuu dib u noqaa badalkaan wuxuuna furaa badalkii ka horeey.Wuxuu kuu fasaxaa in aad ku dartid sababta.',
'tooltip-preferences-save' => 'Kaydi isbedelada',
'tooltip-summary' => 'ku qor qoraal kooban',

# Attribution
'anonymous' => "{{PLURAL:$1|Isticmaalaha|Isticmaaleyaasa}} aanan la'aqoonsanin ee {{SITENAME}}",
'siteuser' => '{{SITENAME}} isticmaalaha $1',
'lastmodifiedatby' => 'Bogaan waxaa ugu dambeyntii wax laga bedelay $2, $1 kana bedelay $3.',
'othercontribs' => 'Waxay ku saleysantahay shaqada $1.',

# Info page
'pageinfo-title' => 'Macluumaad ku saabsan "$1"',
'pageinfo-toolboxlink' => 'Macluumad ku saabsan',

# Browsing diffs
'previousdiff' => '← bedelkii ka duqsanaa',
'nextdiff' => 'Bedelkii ugu cusbaa →',

# Media information
'file-info-size' => '$1 × $2 pixels, weyninka faylka : $3, nuuca MIME: $4',
'file-nohires' => 'Faah faahin dheeraad ah malahan.',

# Special:NewFiles
'imagelisttext' => "Hoos waxaa yaala liiska '''$1''' {{PLURAL:$1|file|faylalka}} oo u kala soocan $2.",
'ilsubmit' => 'Raadi',
'bydate' => 'hab taariikheed',

# Metadata
'metadata-help' => 'Faylkaan wuxuu leeyahay  faah faahin dheeraad ah,waxaa laga yaabaa in lagu  isticmaalay digital kaamiro ama skanner oo lagu sameeyo sawir ama lagu digitilays gareeyay.
Hadii faylka wax laga badalay sida oo markiisa hore ahaa, waxaa laga yaabaa in ee  faah faahinta faylkaan eesan dhameestirneen.',
'metadata-fields' => 'Sawirka qeybihiisa metadata oo ku tixan fariintaan waxaa lagu dari doonaa bogga sawirka meesha laga arko markii miiska metadata la qariyo.Kuwa kale waxaa loo qarinaa sida default.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# Exif tags
'exif-iimcategory' => 'Qeybta',

# External editor support
'edit-externally' => 'wax ka bedel faylkaan adiga oo isticmaalaya brogram dheeraad ah',
'edit-externally-help' => '(Ka fiiri wax war ah oo kale  [//www.mediawiki.org/wiki/Manual:External_editors sidii oo wax ugu habeysmi lahaa] )',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'dhamaan',
'namespacesall' => 'dhamaan',
'monthsall' => 'Dhamaan',

# Email address confirmation
'confirmemail_noemail' => 'Kuma haysatid cinwaan E-boosto sax [[Special:Preferences|isticmaala dooqiisa]].',

# action=watch/unwatch
'confirm-unwatch-top' => 'Boggaan ka saar liiskaaga waardiyaha',

# Multipage image navigation
'imgmultigo' => 'Soco!',

# Table pager
'table_pager_next' => 'Bogga ku xiga',
'table_pager_first' => 'Bogga ugu horeeyo',
'table_pager_last' => 'Bogga ugu danbeeyo',

# Auto-summaries
'autosumm-blank' => 'Masaxay bogga',
'autosumm-replace' => 'Wuxuu qoraalka ku badalay "$1"',
'autosumm-new' => 'Bog cusub: $1',

# Watchlist editor
'watchlistedit-normal-legend' => 'Ka saar ciwaanada liiska waardiyaha',
'watchlistedit-normal-explain' => 'Ciwaanada ee liiskaada waardiyaha hoos ayaa lagu soo ban dhigay.
Si aad u tirtito Ciwaanka, Godka udhow calaameey, ee guji "{{int:Watchlistedit-normal-submit}}".
waxaad awoodaa [[Special:EditWatchlist/raw|Liiska wax ka bedel]].',
'watchlistedit-raw-legend' => 'Badal liiska waardiyeenta ceeriinka ah',

# Watchlist editing tools
'watchlisttools-view' => 'Itusi isbedelada jiro',
'watchlisttools-edit' => 'Fiiri iyo wax ka badal liiska waardiyaha',
'watchlisttools-raw' => 'Badal liiska waardiyeenta ceeriinka ah',

# Special:Version
'version-poweredby-others' => 'kuwa kale',

# Special:Redirect
'redirect-file' => 'Magaca faylka',

# Special:FileDuplicateSearch
'fileduplicatesearch-legend' => 'Raadi mid tusaale ah',
'fileduplicatesearch-submit' => 'Raadi',

# Special:SpecialPages
'specialpages' => 'bogagga khaaska ah',
'specialpages-group-pages' => 'liiska maqaalada',

# Special:BlankPage
'blankpage' => 'Bog masaxan',

# Special:Tags
'tag-filter' => '[[Special:Tags|Filtaraha]] tag:',

# Database error messages
'dberr-usegoogle' => 'Waxaa baroobeen kartaa in aad ka raadiso google',

# HTML forms
'htmlform-reset' => 'Ka noqo wax bedelka',
'htmlform-selectorother-other' => 'kuwa kale',

# New logging system
'rightsnone' => '(waxna)',

# Feedback
'feedback-message' => 'Fariinta:',

# Search suggestions
'searchsuggest-search' => 'Raadi',

# API errors
'api-error-copyuploaddisabled' => 'Soo gelinta dhinaca URL-ka waa laga damiyay kombiyuutarkaan',
'api-error-filename-tooshort' => 'Magaca faylka aad oo u gaabanyahay',
'api-error-filetype-banned' => 'Faylka nuucaan waa laga mamnuucay',
'api-error-http' => 'Qalad gudaha ah: Ma ku xiro karo kombiyutarka',
'api-error-illegal-filename' => 'Magaca faylkaan lama ogola.',
'api-error-mustbeloggedin' => 'Waa in aad gudaha u soo gashaa hadii aad rabtid in aad fayl soo geliso.',
'api-error-ok-but-empty' => 'Qalad gudaha ah : kombiyutarka maka soo jawaabin',
'api-error-unclassified' => 'Qalad la aqoon aa dhacay',
'api-error-unknown-code' => 'Qalad la aqoon: "$1"',
'api-error-unknown-warning' => 'Digniin la aqoon: $1',
'api-error-uploaddisabled' => 'Soo gelinta waa laga xiray wikigaan.',

# Limit report
'limitreport-cputime' => 'Waqtiga adeegsiga CPU',
'limitreport-walltime' => 'Waqtiga dhabta ah adeegsiga',

);
